# ACT I

### SCENE I. Windsor. Before PAGE's house.

_Enter SHALLOW, SLENDER, and SIR HUGH EVANS_

**SHALLOW**  
Sir Hugh, persuade me not; I will make a Star-  
chamber matter of it: if he were twenty Sir John  
Falstaffs, he shall not abuse Robert Shallow, esquire.  

**SLENDER**  
In the county of Gloucester, justice of peace and  
'Coram.'  

**SHALLOW**  
Ay, cousin Slender, and 'Custalourum.  

**SLENDER**  
Ay, and 'Rato-lorum' too; and a gentleman born,  
master parson; who writes himself 'Armigero,' in any  
bill, warrant, quittance, or obligation, 'Armigero.'  

**SHALLOW**  
Ay, that I do; and have done any time these three  
hundred years.  

**SLENDER**  
All his successors gone before him hath done't; and  
all his ancestors that come after him may: they may  
give the dozen white luces in their coat.  

**SHALLOW**  
It is an old coat.  

**SIR HUGH EVANS**  
The dozen white louses do become an old coat well;  
it agrees well, passant; it is a familiar beast to  
man, and signifies love.  

**SHALLOW**  
The luce is the fresh fish; the salt fish is an old coat.  

**SLENDER**  
I may quarter, coz.  

**SHALLOW**  
You may, by marrying.  

**SIR HUGH EVANS**  
It is marring indeed, if he quarter it.  

**SHALLOW**  
Not a whit.  

**SIR HUGH EVANS**  
Yes, py'r lady; if he has a quarter of your coat,  
there is but three skirts for yourself, in my  
simple conjectures: but that is all one. If Sir  
John Falstaff have committed disparagements unto  
you, I am of the church, and will be glad to do my  
benevolence to make atonements and compremises  
between you.  

**SHALLOW**  
The council shall bear it; it is a riot.  

**SIR HUGH EVANS**  
It is not meet the council hear a riot; there is no  
fear of Got in a riot: the council, look you, shall  
desire to hear the fear of Got, and not to hear a  
riot; take your vizaments in that.  

**SHALLOW**  
Ha! o' my life, if I were young again, the sword  
should end it.  

**SIR HUGH EVANS**  
It is petter that friends is the sword, and end it:  
and there is also another device in my prain, which  
peradventure prings goot discretions with it: there  
is Anne Page, which is daughter to Master Thomas  
Page, which is pretty virginity.  

**SLENDER**  
Mistress Anne Page? She has brown hair, and speaks  
small like a woman.  

**SIR HUGH EVANS**  
It is that fery person for all the orld, as just as  
you will desire; and seven hundred pounds of moneys,  
and gold and silver, is her grandsire upon his  
death's-bed--Got deliver to a joyful resurrections!  
\--give, when she is able to overtake seventeen years  
old: it were a goot motion if we leave our pribbles  
and prabbles, and desire a marriage between Master  
Abraham and Mistress Anne Page.  

**SLENDER**  
Did her grandsire leave her seven hundred pound?  

**SIR HUGH EVANS**  
Ay, and her father is make her a petter penny.  

**SLENDER**  
I know the young gentlewoman; she has good gifts.  

**SIR HUGH EVANS**  
Seven hundred pounds and possibilities is goot gifts.  

**SHALLOW**  
Well, let us see honest Master Page. Is Falstaff there?  

**SIR HUGH EVANS**  
Shall I tell you a lie? I do despise a liar as I do  
despise one that is false, or as I despise one that  
is not true. The knight, Sir John, is there; and, I  
beseech you, be ruled by your well-willers. I will  
peat the door for Master Page.  

_Knocks_

What, hoa! Got pless your house here!  

**PAGE**  
[Within]_  
Who's there?  

_Enter PAGE_

**SIR HUGH EVANS**  
Here is Got's plessing, and your friend, and Justice  
Shallow; and here young Master Slender, that  
peradventures shall tell you another tale, if  
matters grow to your likings.  

**PAGE**  
I am glad to see your worships well.  
I thank you for my venison, Master Shallow.  

**SHALLOW**  
Master Page, I am glad to see you: much good do it  
your good heart! I wished your venison better; it  
was ill killed. How doth good Mistress Page?--and I  
thank you always with my heart, la! with my heart.  

**PAGE**  
Sir, I thank you.  

**SHALLOW**  
Sir, I thank you; by yea and no, I do.  

**PAGE**  
I am glad to see you, good Master Slender.  

**SLENDER**  
How does your fallow greyhound, sir? I heard say he  
was outrun on Cotsall.  

**PAGE**  
It could not be judged, sir.  

**SLENDER**  
You'll not confess, you'll not confess.  

**SHALLOW**  
That he will not. 'Tis your fault, 'tis your fault;  
'tis a good dog.  

**PAGE**  
A cur, sir.  

**SHALLOW**  
Sir, he's a good dog, and a fair dog: can there be  
more said? he is good and fair. Is Sir John  
Falstaff here?  

**PAGE**  
Sir, he is within; and I would I could do a good  
office between you.  

**SIR HUGH EVANS**  
It is spoke as a Christians ought to speak.  

**SHALLOW**  
He hath wronged me, Master Page.  

**PAGE**  
Sir, he doth in some sort confess it.  

**SHALLOW**  
If it be confessed, it is not redress'd: is not that  
so, Master Page? He hath wronged me; indeed he  
hath, at a word, he hath, believe me: Robert  
Shallow, esquire, saith, he is wronged.  

**PAGE**  
Here comes Sir John.  

_Enter FALSTAFF, BARDOLPH, NYM, and PISTOL_

**FALSTAFF**  
Now, Master Shallow, you'll complain of me to the king?  

**SHALLOW**  
Knight, you have beaten my men, killed my deer, and  
broke open my lodge.  

**FALSTAFF**  
But not kissed your keeper's daughter?  

**SHALLOW**  
Tut, a pin! this shall be answered.  

**FALSTAFF**  
I will answer it straight; I have done all this.  
That is now answered.  

**SHALLOW**  
The council shall know this.  

**FALSTAFF**  
'Twere better for you if it were known in counsel:  
you'll be laughed at.  

**SIR HUGH EVANS**  
Pauca verba, Sir John; goot worts.  

**FALSTAFF**  
Good worts! good cabbage. Slender, I broke your  
head: what matter have you against me?  

**SLENDER**  
Marry, sir, I have matter in my head against you;  
and against your cony-catching rascals, Bardolph,  
Nym, and Pistol.  

**BARDOLPH**  
You Banbury cheese!  

**SLENDER**  
Ay, it is no matter.  

**PISTOL**  
How now, Mephostophilus!  

**SLENDER**  
Ay, it is no matter.  

**NYM**  
Slice, I say! pauca, pauca: slice! that's my humour.  

**SLENDER**  
Where's Simple, my man? Can you tell, cousin?  

**SIR HUGH EVANS**  
Peace, I pray you. Now let us understand. There is  
three umpires in this matter, as I understand; that  
is, Master Page, fidelicet Master Page; and there is  
myself, fidelicet myself; and the three party is,  
lastly and finally, mine host of the Garter.  

**PAGE**  
We three, to hear it and end it between them.  

**SIR HUGH EVANS**  
Fery goot: I will make a prief of it in my note-  
book; and we will afterwards ork upon the cause with  
as great discreetly as we can.  

**FALSTAFF**  
Pistol!  

**PISTOL**  
He hears with ears.  

**SIR HUGH EVANS**  
The tevil and his tam! what phrase is this, 'He  
hears with ear'? why, it is affectations.  

**FALSTAFF**  
Pistol, did you pick Master Slender's purse?  

**SLENDER**  
Ay, by these gloves, did he, or I would I might  
never come in mine own great chamber again else, of  
seven groats in mill-sixpences, and two Edward  
shovel-boards, that cost me two shilling and two  
pence apiece of Yead Miller, by these gloves.  

**FALSTAFF**  
Is this true, Pistol?  

**SIR HUGH EVANS**  
No; it is false, if it is a pick-purse.  

**PISTOL**  
Ha, thou mountain-foreigner! Sir John and Master mine,  
I combat challenge of this latten bilbo.  
Word of denial in thy labras here!  
Word of denial: froth and scum, thou liest!  

**SLENDER**  
By these gloves, then, 'twas he.  

**NYM**  
Be avised, sir, and pass good humours: I will say  
'marry trap' with you, if you run the nuthook's  
humour on me; that is the very note of it.  

**SLENDER**  
By this hat, then, he in the red face had it; for  
though I cannot remember what I did when you made me  
drunk, yet I am not altogether an ass.  

**FALSTAFF**  
What say you, Scarlet and John?  

**BARDOLPH**  
Why, sir, for my part I say the gentleman had drunk  
himself out of his five sentences.  

**SIR HUGH EVANS**  
It is his five senses: fie, what the ignorance is!  

**BARDOLPH**  
And being fap, sir, was, as they say, cashiered; and  
so conclusions passed the careires.  

**SLENDER**  
Ay, you spake in Latin then too; but 'tis no  
matter: I'll ne'er be drunk whilst I live again,  
but in honest, civil, godly company, for this trick:  
if I be drunk, I'll be drunk with those that have  
the fear of God, and not with drunken knaves.  

**SIR HUGH EVANS**  
So Got udge me, that is a virtuous mind.  

**FALSTAFF**  
You hear all these matters denied, gentlemen; you hear it.  

_Enter ANNE PAGE, with wine; MISTRESS FORD and MISTRESS PAGE, following_

**PAGE**  
Nay, daughter, carry the wine in; we'll drink within.  

_Exit ANNE PAGE_

**SLENDER**  
O heaven! this is Mistress Anne Page.  

**PAGE**  
How now, Mistress Ford!  

**FALSTAFF**  
Mistress Ford, by my troth, you are very well met:  
by your leave, good mistress.  

_Kisses her_

**PAGE**  
Wife, bid these gentlemen welcome. Come, we have a  
hot venison pasty to dinner: come, gentlemen, I hope  
we shall drink down all unkindness.  

_Exeunt all except SHALLOW, SLENDER, and SIR HUGH EVANS_

**SLENDER**  
I had rather than forty shillings I had my Book of  
Songs and Sonnets here.  

_Enter SIMPLE_

How now, Simple! where have you been? I must wait  
on myself, must I? You have not the Book of Riddles  
about you, have you?  

**SIMPLE**  
Book of Riddles! why, did you not lend it to Alice  
Shortcake upon All-hallowmas last, a fortnight  
afore Michaelmas?  

**SHALLOW**  
Come, coz; come, coz; we stay for you. A word with  
you, coz; marry, this, coz: there is, as 'twere, a  
tender, a kind of tender, made afar off by Sir Hugh  
here. Do you understand me?  

**SLENDER**  
Ay, sir, you shall find me reasonable; if it be so,  
I shall do that that is reason.  

**SHALLOW**  
Nay, but understand me.  

**SLENDER**  
So I do, sir.  

**SIR HUGH EVANS**  
Give ear to his motions, Master Slender: I will  
description the matter to you, if you be capacity of it.  

**SLENDER**  
Nay, I will do as my cousin Shallow says: I pray  
you, pardon me; he's a justice of peace in his  
country, simple though I stand here.  

**SIR HUGH EVANS**  
But that is not the question: the question is  
concerning your marriage.  

**SHALLOW**  
Ay, there's the point, sir.  

**SIR HUGH EVANS**  
Marry, is it; the very point of it; to Mistress Anne Page.  

**SLENDER**  
Why, if it be so, I will marry her upon any  
reasonable demands.  

**SIR HUGH EVANS**  
But can you affection the 'oman? Let us command to  
know that of your mouth or of your lips; for divers  
philosophers hold that the lips is parcel of the  
mouth. Therefore, precisely, can you carry your  
good will to the maid?  

**SHALLOW**  
Cousin Abraham Slender, can you love her?  

**SLENDER**  
I hope, sir, I will do as it shall become one that  
would do reason.  

**SIR HUGH EVANS**  
Nay, Got's lords and his ladies! you must speak  
possitable, if you can carry her your desires  
towards her.  

**SHALLOW**  
That you must. Will you, upon good dowry, marry her?  

**SLENDER**  
I will do a greater thing than that, upon your  
request, cousin, in any reason.  

**SHALLOW**  
Nay, conceive me, conceive me, sweet coz: what I do  
is to pleasure you, coz. Can you love the maid?  

**SLENDER**  
I will marry her, sir, at your request: but if there  
be no great love in the beginning, yet heaven may  
decrease it upon better acquaintance, when we are  
married and have more occasion to know one another;  
I hope, upon familiarity will grow more contempt:  
but if you say, 'Marry her,' I will marry her; that  
I am freely dissolved, and dissolutely.  

**SIR HUGH EVANS**  
It is a fery discretion answer; save the fall is in  
the ort 'dissolutely:' the ort is, according to our  
meaning, 'resolutely:' his meaning is good.  

**SHALLOW**  
Ay, I think my cousin meant well.  

**SLENDER**  
Ay, or else I would I might be hanged, la!  

**SHALLOW**  
Here comes fair Mistress Anne.  

_Re-enter ANNE PAGE_

Would I were young for your sake, Mistress Anne!  

**ANNE PAGE**  
The dinner is on the table; my father desires your  
worships' company.  

**SHALLOW**  
I will wait on him, fair Mistress Anne.  

**SIR HUGH EVANS**  
Od's plessed will! I will not be absence at the grace.  

_Exeunt SHALLOW and SIR HUGH EVANS_

**ANNE PAGE**  
Will't please your worship to come in, sir?  

**SLENDER**  
No, I thank you, forsooth, heartily; I am very well.  

**ANNE PAGE**  
The dinner attends you, sir.  

**SLENDER**  
I am not a-hungry, I thank you, forsooth. Go,  
sirrah, for all you are my man, go wait upon my  
cousin Shallow.  

_Exit SIMPLE_

A justice of peace sometimes may be beholding to his  
friend for a man. I keep but three men and a boy  
yet, till my mother be dead: but what though? Yet I  
live like a poor gentleman born.  

**ANNE PAGE**  
I may not go in without your worship: they will not  
sit till you come.  

**SLENDER**  
I' faith, I'll eat nothing; I thank you as much as  
though I did.  

**ANNE PAGE**  
I pray you, sir, walk in.  

**SLENDER**  
I had rather walk here, I thank you. I bruised  
my shin th' other day with playing at sword and  
dagger with a master of fence; three veneys for a  
dish of stewed prunes; and, by my troth, I cannot  
abide the smell of hot meat since. Why do your  
dogs bark so? be there bears i' the town?  

**ANNE PAGE**  
I think there are, sir; I heard them talked of.  

**SLENDER**  
I love the sport well but I shall as soon quarrel at  
it as any man in England. You are afraid, if you see  
the bear loose, are you not?  

**ANNE PAGE**  
Ay, indeed, sir.  

**SLENDER**  
That's meat and drink to me, now. I have seen  
Sackerson loose twenty times, and have taken him by  
the chain; but, I warrant you, the women have so  
cried and shrieked at it, that it passed: but women,  
indeed, cannot abide 'em; they are very ill-favored  
rough things.  

_Re-enter PAGE_

**PAGE**  
Come, gentle Master Slender, come; we stay for you.  

**SLENDER**  
I'll eat nothing, I thank you, sir.  

**PAGE**  
By cock and pie, you shall not choose, sir! come, come.  

**SLENDER**  
Nay, pray you, lead the way.  

**PAGE**  
Come on, sir.  

**SLENDER**  
Mistress Anne, yourself shall go first.  

**ANNE PAGE**  
Not I, sir; pray you, keep on.  

**SLENDER**  
I'll rather be unmannerly than troublesome.  
You do yourself wrong, indeed, la!  

_Exeunt_

### SCENE II. The same.

_Enter SIR HUGH EVANS and SIMPLE_

**SIR HUGH EVANS**  
Go your ways, and ask of Doctor Caius' house which  
is the way: and there dwells one Mistress Quickly,  
which is in the manner of his nurse, or his dry  
nurse, or his cook, or his laundry, his washer, and  
his wringer.  

**SIMPLE**  
Well, sir.  

**SIR HUGH EVANS**  
Nay, it is petter yet. Give her this letter; for it  
is a 'oman that altogether's acquaintance with  
Mistress Anne Page: and the letter is, to desire  
and require her to solicit your master's desires to  
Mistress Anne Page. I pray you, be gone: I will  
make an end of my dinner; there's pippins and cheese to come.  

_Exeunt_

### SCENE III. A room in the Garter Inn.

_Enter FALSTAFF, Host, BARDOLPH, NYM, PISTOL, and ROBIN_

**FALSTAFF**  
Mine host of the Garter!  

**Host**  
What says my bully-rook? speak scholarly and wisely.  

**FALSTAFF**  
Truly, mine host, I must turn away some of my  
followers.  

**Host**  
Discard, bully Hercules; cashier: let them wag; trot, trot.  

**FALSTAFF**  
I sit at ten pounds a week.  

**Host**  
Thou'rt an emperor, Caesar, Keisar, and Pheezar. I  
will entertain Bardolph; he shall draw, he shall  
tap: said I well, bully Hector?  

**FALSTAFF**  
Do so, good mine host.  

**Host**  
I have spoke; let him follow.  

_[To BARDOLPH]_  
Let me see thee froth and lime: I am at a word; follow.  

_Exit_

**FALSTAFF**  
Bardolph, follow him. A tapster is a good trade:  
an old cloak makes a new jerkin; a withered  
serving-man a fresh tapster. Go; adieu.  

**BARDOLPH**  
It is a life that I have desired: I will thrive.  

**PISTOL**  
O base Hungarian wight! wilt thou the spigot wield?  

_Exit BARDOLPH_

**NYM**  
He was gotten in drink: is not the humour conceited?  

**FALSTAFF**  
I am glad I am so acquit of this tinderbox: his  
thefts were too open; his filching was like an  
unskilful singer; he kept not time.  

**NYM**  
The good humour is to steal at a minute's rest.  

**PISTOL**  
'Convey,' the wise it call. 'Steal!' foh! a fico  
for the phrase!  

**FALSTAFF**  
Well, sirs, I am almost out at heels.  

**PISTOL**  
Why, then, let kibes ensue.  

**FALSTAFF**  
There is no remedy; I must cony-catch; I must shift.  

**PISTOL**  
Young ravens must have food.  

**FALSTAFF**  
Which of you know Ford of this town?  

**PISTOL**  
I ken the wight: he is of substance good.  

**FALSTAFF**  
My honest lads, I will tell you what I am about.  

**PISTOL**  
Two yards, and more.  

**FALSTAFF**  
No quips now, Pistol! Indeed, I am in the waist two  
yards about; but I am now about no waste; I am about  
thrift. Briefly, I do mean to make love to Ford's  
wife: I spy entertainment in her; she discourses,  
she carves, she gives the leer of invitation: I  
can construe the action of her familiar style; and  
the hardest voice of her behavior, to be Englished  
rightly, is, 'I am Sir John Falstaff's.'  

**PISTOL**  
He hath studied her will, and translated her will,  
out of honesty into English.  

**NYM**  
The anchor is deep: will that humour pass?  

**FALSTAFF**  
Now, the report goes she has all the rule of her  
husband's purse: he hath a legion of angels.  

**PISTOL**  
As many devils entertain; and 'To her, boy,' say I.  

**NYM**  
The humour rises; it is good: humour me the angels.  

**FALSTAFF**  
I have writ me here a letter to her: and here  
another to Page's wife, who even now gave me good  
eyes too, examined my parts with most judicious  
oeillades; sometimes the beam of her view gilded my  
foot, sometimes my portly belly.  

**PISTOL**  
Then did the sun on dunghill shine.  

**NYM**  
I thank thee for that humour.  

**FALSTAFF**  
O, she did so course o'er my exteriors with such a  
greedy intention, that the appetite of her eye did  
seem to scorch me up like a burning-glass! Here's  
another letter to her: she bears the purse too; she  
is a region in Guiana, all gold and bounty. I will  
be cheater to them both, and they shall be  
exchequers to me; they shall be my East and West  
Indies, and I will trade to them both. Go bear thou  
this letter to Mistress Page; and thou this to  
Mistress Ford: we will thrive, lads, we will thrive.  

**PISTOL**  
Shall I Sir Pandarus of Troy become,  
And by my side wear steel? then, Lucifer take all!  

**NYM**  
I will run no base humour: here, take the  
humour-letter: I will keep the havior of reputation.  

**FALSTAFF**  
[To ROBIN]_  
Hold, sirrah, bear you these letters tightly;  
Sail like my pinnace to these golden shores.  
Rogues, hence, avaunt! vanish like hailstones, go;  
Trudge, plod away o' the hoof; seek shelter, pack!  
Falstaff will learn the humour of the age,  
French thrift, you rogues; myself and skirted page.  

_Exeunt FALSTAFF and ROBIN_

**PISTOL**  
Let vultures gripe thy guts! for gourd and fullam holds,  
And high and low beguiles the rich and poor:  
Tester I'll have in pouch when thou shalt lack,  
Base Phrygian Turk!  

**NYM**  
I have operations which be humours of revenge.  

**PISTOL**  
Wilt thou revenge?  

**NYM**  
By welkin and her star!  

**PISTOL**  
With wit or steel?  

**NYM**  
With both the humours, I:  
I will discuss the humour of this love to Page.  

**PISTOL**  
And I to Ford shall eke unfold  
How Falstaff, varlet vile,  
His dove will prove, his gold will hold,  
And his soft couch defile.  

**NYM**  
My humour shall not cool: I will incense Page to  
deal with poison; I will possess him with  
yellowness, for the revolt of mine is dangerous:  
that is my true humour.  

**PISTOL**  
Thou art the Mars of malecontents: I second thee; troop on.  

_Exeunt_

### SCENE IV. A room in DOCTOR CAIUS' house.

_Enter MISTRESS QUICKLY, SIMPLE, and RUGBY_

**MISTRESS QUICKLY**  
What, John Rugby! I pray thee, go to the casement,  
and see if you can see my master, Master Doctor  
Caius, coming. If he do, i' faith, and find any  
body in the house, here will be an old abusing of  
God's patience and the king's English.  

**RUGBY**  
I'll go watch.  

**MISTRESS QUICKLY**  
Go; and we'll have a posset for't soon at night, in  
faith, at the latter end of a sea-coal fire.  

_Exit RUGBY_

An honest, willing, kind fellow, as ever servant  
shall come in house withal, and, I warrant you, no  
tell-tale nor no breed-bate: his worst fault is,  
that he is given to prayer; he is something peevish  
that way: but nobody but has his fault; but let  
that pass. Peter Simple, you say your name is?  

**SIMPLE**  
Ay, for fault of a better.  

**MISTRESS QUICKLY**  
And Master Slender's your master?  

**SIMPLE**  
Ay, forsooth.  

**MISTRESS QUICKLY**  
Does he not wear a great round beard, like a  
glover's paring-knife?  

**SIMPLE**  
No, forsooth: he hath but a little wee face, with a  
little yellow beard, a Cain-coloured beard.  

**MISTRESS QUICKLY**  
A softly-sprighted man, is he not?  

**SIMPLE**  
Ay, forsooth: but he is as tall a man of his hands  
as any is between this and his head; he hath fought  
with a warrener.  

**MISTRESS QUICKLY**  
How say you? O, I should remember him: does he not  
hold up his head, as it were, and strut in his gait?  

**SIMPLE**  
Yes, indeed, does he.  

**MISTRESS QUICKLY**  
Well, heaven send Anne Page no worse fortune! Tell  
Master Parson Evans I will do what I can for your  
master: Anne is a good girl, and I wish--  

_Re-enter RUGBY_

**RUGBY**  
Out, alas! here comes my master.  

**MISTRESS QUICKLY**  
We shall all be shent. Run in here, good young man;  
go into this closet: he will not stay long.  

_Shuts SIMPLE in the closet_

What, John Rugby! John! what, John, I say!  
Go, John, go inquire for my master; I doubt  
he be not well, that he comes not home.  

_Singing_

And down, down, adown-a, & c.  

_Enter DOCTOR CAIUS_

**DOCTOR CAIUS**  
Vat is you sing? I do not like des toys. Pray you,  
go and vetch me in my closet un boitier vert, a box,  
a green-a box: do intend vat I speak? a green-a box.  

**MISTRESS QUICKLY**  
Ay, forsooth; I'll fetch it you.  

_[Aside]_  
I am glad he went not in himself: if he had found  
the young man, he would have been horn-mad.  

**DOCTOR CAIUS**  
Fe, fe, fe, fe! ma foi, il fait fort chaud. Je  
m'en vais a la cour--la grande affaire.  

**MISTRESS QUICKLY**  
Is it this, sir?  

**DOCTOR CAIUS**  
Oui; mette le au mon pocket: depeche, quickly. Vere  
is dat knave Rugby?  

**MISTRESS QUICKLY**  
What, John Rugby! John!  

**RUGBY**  
Here, sir!  

**DOCTOR CAIUS**  
You are John Rugby, and you are Jack Rugby. Come,  
take-a your rapier, and come after my heel to the court.  

**RUGBY**  
'Tis ready, sir, here in the porch.  

**DOCTOR CAIUS**  
By my trot, I tarry too long. Od's me!  
Qu'ai-j'oublie! dere is some simples in my closet,  
dat I vill not for the varld I shall leave behind.  

**MISTRESS QUICKLY**  
Ay me, he'll find the young man here, and be mad!  

**DOCTOR CAIUS**  
O diable, diable! vat is in my closet? Villain! larron!  

_Pulling SIMPLE out_

Rugby, my rapier!  

**MISTRESS QUICKLY**  
Good master, be content.  

**DOCTOR CAIUS**  
Wherefore shall I be content-a?  

**MISTRESS QUICKLY**  
The young man is an honest man.  

**DOCTOR CAIUS**  
What shall de honest man do in my closet? dere is  
no honest man dat shall come in my closet.  

**MISTRESS QUICKLY**  
I beseech you, be not so phlegmatic. Hear the truth  
of it: he came of an errand to me from Parson Hugh.  

**DOCTOR CAIUS**  
Vell.  

**SIMPLE**  
Ay, forsooth; to desire her to--  

**MISTRESS QUICKLY**  
Peace, I pray you.  

**DOCTOR CAIUS**  
Peace-a your tongue. Speak-a your tale.  

**SIMPLE**  
To desire this honest gentlewoman, your maid, to  
speak a good word to Mistress Anne Page for my  
master in the way of marriage.  

**MISTRESS QUICKLY**  
This is all, indeed, la! but I'll ne'er put my  
finger in the fire, and need not.  

**DOCTOR CAIUS**  
Sir Hugh send-a you? Rugby, baille me some paper.  
Tarry you a little-a while.  

_Writes_

**MISTRESS QUICKLY**  
[Aside to SIMPLE]_  
I am glad he is so quiet: if he  
had been thoroughly moved, you should have heard him  
so loud and so melancholy. But notwithstanding,  
man, I'll do you your master what good I can: and  
the very yea and the no is, the French doctor, my  
master,--I may call him my master, look you, for I  
keep his house; and I wash, wring, brew, bake,  
scour, dress meat and drink, make the beds and do  
all myself,--  

**SIMPLE**  
[Aside to MISTRESS QUICKLY]_  
'Tis a great charge to  
come under one body's hand.  

**MISTRESS QUICKLY**  
[Aside to SIMPLE]_  
Are you avised o' that? you  
shall find it a great charge: and to be up early  
and down late; but notwithstanding,--to tell you in  
your ear; I would have no words of it,--my master  
himself is in love with Mistress Anne Page: but  
notwithstanding that, I know Anne's mind,--that's  
neither here nor there.  

**DOCTOR CAIUS**  
You jack'nape, give-a this letter to Sir Hugh; by  
gar, it is a shallenge: I will cut his troat in dee  
park; and I will teach a scurvy jack-a-nape priest  
to meddle or make. You may be gone; it is not good  
you tarry here. By gar, I will cut all his two  
stones; by gar, he shall not have a stone to throw  
at his dog:  

_Exit SIMPLE_

**MISTRESS QUICKLY**  
Alas, he speaks but for his friend.  

**DOCTOR CAIUS**  
It is no matter-a ver dat: do not you tell-a me  
dat I shall have Anne Page for myself? By gar, I  
vill kill de Jack priest; and I have appointed mine  
host of de Jarteer to measure our weapon. By gar, I  
will myself have Anne Page.  

**MISTRESS QUICKLY**  
Sir, the maid loves you, and all shall be well. We  
must give folks leave to prate: what, the good-jer!  

**DOCTOR CAIUS**  
Rugby, come to the court with me. By gar, if I have  
not Anne Page, I shall turn your head out of my  
door. Follow my heels, Rugby.  

_Exeunt DOCTOR CAIUS and RUGBY_

**MISTRESS QUICKLY**  
You shall have An fool's-head of your own. No, I  
know Anne's mind for that: never a woman in Windsor  
knows more of Anne's mind than I do; nor can do more  
than I do with her, I thank heaven.  

**FENTON**  
[Within]_  
Who's within there? ho!  

**MISTRESS QUICKLY**  
Who's there, I trow! Come near the house, I pray you.  

_Enter FENTON_

**FENTON**  
How now, good woman? how dost thou?  

**MISTRESS QUICKLY**  
The better that it pleases your good worship to ask.  

**FENTON**  
What news? how does pretty Mistress Anne?  

**MISTRESS QUICKLY**  
In truth, sir, and she is pretty, and honest, and  
gentle; and one that is your friend, I can tell you  
that by the way; I praise heaven for it.  

**FENTON**  
Shall I do any good, thinkest thou? shall I not lose my suit?  

**MISTRESS QUICKLY**  
Troth, sir, all is in his hands above: but  
notwithstanding, Master Fenton, I'll be sworn on a  
book, she loves you. Have not your worship a wart  
above your eye?  

**FENTON**  
Yes, marry, have I; what of that?  

**MISTRESS QUICKLY**  
Well, thereby hangs a tale: good faith, it is such  
another Nan; but, I detest, an honest maid as ever  
broke bread: we had an hour's talk of that wart. I  
shall never laugh but in that maid's company! But  
indeed she is given too much to allicholy and  
musing: but for you--well, go to.  

**FENTON**  
Well, I shall see her to-day. Hold, there's money  
for thee; let me have thy voice in my behalf: if  
thou seest her before me, commend me.  

**MISTRESS QUICKLY**  
Will I? i'faith, that we will; and I will tell your  
worship more of the wart the next time we have  
confidence; and of other wooers.  

**FENTON**  
Well, farewell; I am in great haste now.  

**MISTRESS QUICKLY**  
Farewell to your worship.  

_Exit FENTON_

Truly, an honest gentleman: but Anne loves him not;  
for I know Anne's mind as well as another does. Out  
upon't! what have I forgot?  

_Exit_

# ACT II

### SCENE I. Before PAGE'S house.

_Enter MISTRESS PAGE, with a letter_

**MISTRESS PAGE**  
What, have I scaped love-letters in the holiday-  
time of my beauty, and am I now a subject for them?  
Let me see.  

_[Reads]_  
'Ask me no reason why I love you; for though  
Love use Reason for his physician, he admits him  
not for his counsellor. You are not young, no more  
am I; go to then, there's sympathy: you are merry,  
so am I; ha, ha! then there's more sympathy: you  
love sack, and so do I; would you desire better  
sympathy? Let it suffice thee, Mistress Page,--at  
the least, if the love of soldier can suffice,--  
that I love thee. I will not say, pity me; 'tis  
not a soldier-like phrase: but I say, love me. By me,  
Thine own true knight,  
By day or night,  
Or any kind of light,  
With all his might  
For thee to fight, JOHN FALSTAFF'  
What a Herod of Jewry is this! O wicked  
world! One that is well-nigh worn to pieces with  
age to show himself a young gallant! What an  
unweighed behavior hath this Flemish drunkard  
picked--with the devil's name!--out of my  
conversation, that he dares in this manner assay me?  
Why, he hath not been thrice in my company! What  
should I say to him? I was then frugal of my  
mirth: Heaven forgive me! Why, I'll exhibit a bill  
in the parliament for the putting down of men. How  
shall I be revenged on him? for revenged I will be,  
as sure as his guts are made of puddings.  

_Enter MISTRESS FORD_

**MISTRESS FORD**  
Mistress Page! trust me, I was going to your house.  

**MISTRESS PAGE**  
And, trust me, I was coming to you. You look very  
ill.  

**MISTRESS FORD**  
Nay, I'll ne'er believe that; I have to show to the contrary.  

**MISTRESS PAGE**  
Faith, but you do, in my mind.  

**MISTRESS FORD**  
Well, I do then; yet I say I could show you to the  
contrary. O Mistress Page, give me some counsel!  

**MISTRESS PAGE**  
What's the matter, woman?  

**MISTRESS FORD**  
O woman, if it were not for one trifling respect, I  
could come to such honour!  

**MISTRESS PAGE**  
Hang the trifle, woman! take the honour. What is  
it? dispense with trifles; what is it?  

**MISTRESS FORD**  
If I would but go to hell for an eternal moment or so,  
I could be knighted.  

**MISTRESS PAGE**  
What? thou liest! Sir Alice Ford! These knights  
will hack; and so thou shouldst not alter the  
article of thy gentry.  

**MISTRESS FORD**  
We burn daylight: here, read, read; perceive how I  
might be knighted. I shall think the worse of fat  
men, as long as I have an eye to make difference of  
men's liking: and yet he would not swear; praised  
women's modesty; and gave such orderly and  
well-behaved reproof to all uncomeliness, that I  
would have sworn his disposition would have gone to  
the truth of his words; but they do no more adhere  
and keep place together than the Hundredth Psalm to  
the tune of 'Green Sleeves.' What tempest, I trow,  
threw this whale, with so many tuns of oil in his  
belly, ashore at Windsor? How shall I be revenged  
on him? I think the best way were to entertain him  
with hope, till the wicked fire of lust have melted  
him in his own grease. Did you ever hear the like?  

**MISTRESS PAGE**  
Letter for letter, but that the name of Page and  
Ford differs! To thy great comfort in this mystery  
of ill opinions, here's the twin-brother of thy  
letter: but let thine inherit first; for, I  
protest, mine never shall. I warrant he hath a  
thousand of these letters, writ with blank space for  
different names--sure, more,--and these are of the  
second edition: he will print them, out of doubt;  
for he cares not what he puts into the press, when  
he would put us two. I had rather be a giantess,  
and lie under Mount Pelion. Well, I will find you  
twenty lascivious turtles ere one chaste man.  

**MISTRESS FORD**  
Why, this is the very same; the very hand, the very  
words. What doth he think of us?  

**MISTRESS PAGE**  
Nay, I know not: it makes me almost ready to  
wrangle with mine own honesty. I'll entertain  
myself like one that I am not acquainted withal;  
for, sure, unless he know some strain in me, that I  
know not myself, he would never have boarded me in this fury.  

**MISTRESS FORD**  
'Boarding,' call you it? I'll be sure to keep him  
above deck.  

**MISTRESS PAGE**  
So will I if he come under my hatches, I'll never  
to sea again. Let's be revenged on him: let's  
appoint him a meeting; give him a show of comfort in  
his suit and lead him on with a fine-baited delay,  
till he hath pawned his horses to mine host of the Garter.  

**MISTRESS FORD**  
Nay, I will consent to act any villany against him,  
that may not sully the chariness of our honesty. O,  
that my husband saw this letter! it would give  
eternal food to his jealousy.  

**MISTRESS PAGE**  
Why, look where he comes; and my good man too: he's  
as far from jealousy as I am from giving him cause;  
and that I hope is an unmeasurable distance.  

**MISTRESS FORD**  
You are the happier woman.  

**MISTRESS PAGE**  
Let's consult together against this greasy knight.  
Come hither.  

_They retire_

_Enter FORD with PISTOL, and PAGE with NYM_

**FORD**  
Well, I hope it be not so.  

**PISTOL**  
Hope is a curtal dog in some affairs:  
Sir John affects thy wife.  

**FORD**  
Why, sir, my wife is not young.  

**PISTOL**  
He wooes both high and low, both rich and poor,  
Both young and old, one with another, Ford;  
He loves the gallimaufry: Ford, perpend.  

**FORD**  
Love my wife!  

**PISTOL**  
With liver burning hot. Prevent, or go thou,  
Like Sir Actaeon he, with Ringwood at thy heels:  
O, odious is the name!  

**FORD**  
What name, sir?  

**PISTOL**  
The horn, I say. Farewell.  
Take heed, have open eye, for thieves do foot by night:  
Take heed, ere summer comes or cuckoo-birds do sing.  
Away, Sir Corporal Nym!  
Believe it, Page; he speaks sense.  

_Exit_

**FORD**  
[Aside]_  
I will be patient; I will find out this.  

**NYM**  
[To PAGE]_  
And this is true; I like not the humour  
of lying. He hath wronged me in some humours: I  
should have borne the humoured letter to her; but I  
have a sword and it shall bite upon my necessity.  
He loves your wife; there's the short and the long.  
My name is Corporal Nym; I speak and I avouch; 'tis  
true: my name is Nym and Falstaff loves your wife.  
Adieu. I love not the humour of bread and cheese,  
and there's the humour of it. Adieu.  

_Exit_

**PAGE**  
'The humour of it,' quoth a'! here's a fellow  
frights English out of his wits.  

**FORD**  
I will seek out Falstaff.  

**PAGE**  
I never heard such a drawling, affecting rogue.  

**FORD**  
If I do find it: well.  

**PAGE**  
I will not believe such a Cataian, though the priest  
o' the town commended him for a true man.  

**FORD**  
'Twas a good sensible fellow: well.  

**PAGE**  
How now, Meg!  

_MISTRESS PAGE and MISTRESS FORD come forward_

**MISTRESS PAGE**  
Whither go you, George? Hark you.  

**MISTRESS FORD**  
How now, sweet Frank! why art thou melancholy?  

**FORD**  
I melancholy! I am not melancholy. Get you home, go.  

**MISTRESS FORD**  
Faith, thou hast some crotchets in thy head. Now,  
will you go, Mistress Page?  

**MISTRESS PAGE**  
Have with you. You'll come to dinner, George.  

_Aside to MISTRESS FORD_

Look who comes yonder: she shall be our messenger  
to this paltry knight.  

**MISTRESS FORD**  
[Aside to MISTRESS PAGE]_  
Trust me, I thought on her:  
she'll fit it.  

_Enter MISTRESS QUICKLY_

**MISTRESS PAGE**  
You are come to see my daughter Anne?  

**MISTRESS QUICKLY**  
Ay, forsooth; and, I pray, how does good Mistress Anne?  

**MISTRESS PAGE**  
Go in with us and see: we have an hour's talk with  
you.  

_Exeunt MISTRESS PAGE, MISTRESS FORD, and MISTRESS QUICKLY_

**PAGE**  
How now, Master Ford!  

**FORD**  
You heard what this knave told me, did you not?  

**PAGE**  
Yes: and you heard what the other told me?  

**FORD**  
Do you think there is truth in them?  

**PAGE**  
Hang 'em, slaves! I do not think the knight would  
offer it: but these that accuse him in his intent  
towards our wives are a yoke of his discarded men;  
very rogues, now they be out of service.  

**FORD**  
Were they his men?  

**PAGE**  
Marry, were they.  

**FORD**  
I like it never the better for that. Does he lie at  
the Garter?  

**PAGE**  
Ay, marry, does he. If he should intend this voyage  
towards my wife, I would turn her loose to him; and  
what he gets more of her than sharp words, let it  
lie on my head.  

**FORD**  
I do not misdoubt my wife; but I would be loath to  
turn them together. A man may be too confident: I  
would have nothing lie on my head: I cannot be thus satisfied.  

**PAGE**  
Look where my ranting host of the Garter comes:  
there is either liquor in his pate or money in his  
purse when he looks so merrily.  

_Enter Host_

How now, mine host!  

**Host**  
How now, bully-rook! thou'rt a gentleman.  
Cavaleiro-justice, I say!  

_Enter SHALLOW_

**SHALLOW**  
I follow, mine host, I follow. Good even and  
twenty, good Master Page! Master Page, will you go  
with us? we have sport in hand.  

**Host**  
Tell him, cavaleiro-justice; tell him, bully-rook.  

**SHALLOW**  
Sir, there is a fray to be fought between Sir Hugh  
the Welsh priest and Caius the French doctor.  

**FORD**  
Good mine host o' the Garter, a word with you.  

_Drawing him aside_

**Host**  
What sayest thou, my bully-rook?  

**SHALLOW**  
[To PAGE]_  
Will you go with us to behold it? My  
merry host hath had the measuring of their weapons;  
and, I think, hath appointed them contrary places;  
for, believe me, I hear the parson is no jester.  
Hark, I will tell you what our sport shall be.  

_They converse apart_

**Host**  
Hast thou no suit against my knight, my  
guest-cavaleire?  

**FORD**  
None, I protest: but I'll give you a pottle of  
burnt sack to give me recourse to him and tell him  
my name is Brook; only for a jest.  

**Host**  
My hand, bully; thou shalt have egress and regress;  
\--said I well?--and thy name shall be Brook. It is  
a merry knight. Will you go, An-heires?  

**SHALLOW**  
Have with you, mine host.  

**PAGE**  
I have heard the Frenchman hath good skill in  
his rapier.  

**SHALLOW**  
Tut, sir, I could have told you more. In these times  
you stand on distance, your passes, stoccadoes, and  
I know not what: 'tis the heart, Master Page; 'tis  
here, 'tis here. I have seen the time, with my long  
sword I would have made you four tall fellows skip like rats.  

**Host**  
Here, boys, here, here! shall we wag?  

**PAGE**  
Have with you. I would rather hear them scold than fight.  

_Exeunt Host, SHALLOW, and PAGE_

**FORD**  
Though Page be a secure fool, an stands so firmly  
on his wife's frailty, yet I cannot put off my  
opinion so easily: she was in his company at Page's  
house; and what they made there, I know not. Well,  
I will look further into't: and I have a disguise  
to sound Falstaff. If I find her honest, I lose not  
my labour; if she be otherwise, 'tis labour well bestowed.  

_Exit_

### SCENE II. A room in the Garter Inn.

_Enter FALSTAFF and PISTOL_

**FALSTAFF**  
I will not lend thee a penny.  

**PISTOL**  
Why, then the world's mine oyster.  
Which I with sword will open.  

**FALSTAFF**  
Not a penny. I have been content, sir, you should  
lay my countenance to pawn; I have grated upon my  
good friends for three reprieves for you and your  
coach-fellow Nym; or else you had looked through  
the grate, like a geminy of baboons. I am damned in  
hell for swearing to gentlemen my friends, you were  
good soldiers and tall fellows; and when Mistress  
Bridget lost the handle of her fan, I took't upon  
mine honour thou hadst it not.  

**PISTOL**  
Didst not thou share? hadst thou not fifteen pence?  

**FALSTAFF**  
Reason, you rogue, reason: thinkest thou I'll  
endanger my soul gratis? At a word, hang no more  
about me, I am no gibbet for you. Go. A short knife  
and a throng! To your manor of Pickt-hatch! Go.  
You'll not bear a letter for me, you rogue! you  
stand upon your honour! Why, thou unconfinable  
baseness, it is as much as I can do to keep the  
terms of my honour precise: I, I, I myself  
sometimes, leaving the fear of God on the left hand  
and hiding mine honour in my necessity, am fain to  
shuffle, to hedge and to lurch; and yet you, rogue,  
will ensconce your rags, your cat-a-mountain  
looks, your red-lattice phrases, and your  
bold-beating oaths, under the shelter of your  
honour! You will not do it, you!  

**PISTOL**  
I do relent: what would thou more of man?  

_Enter ROBIN_

**ROBIN**  
Sir, here's a woman would speak with you.  

**FALSTAFF**  
Let her approach.  

_Enter MISTRESS QUICKLY_

**MISTRESS QUICKLY**  
Give your worship good morrow.  

**FALSTAFF**  
Good morrow, good wife.  

**MISTRESS QUICKLY**  
Not so, an't please your worship.  

**FALSTAFF**  
Good maid, then.  

**MISTRESS QUICKLY**  
I'll be sworn,  
As my mother was, the first hour I was born.  

**FALSTAFF**  
I do believe the swearer. What with me?  

**MISTRESS QUICKLY**  
Shall I vouchsafe your worship a word or two?  

**FALSTAFF**  
Two thousand, fair woman: and I'll vouchsafe thee  
the hearing.  

**MISTRESS QUICKLY**  
There is one Mistress Ford, sir:--I pray, come a  
little nearer this ways:--I myself dwell with master  
Doctor Caius,--  

**FALSTAFF**  
Well, on: Mistress Ford, you say,--  

**MISTRESS QUICKLY**  
Your worship says very true: I pray your worship,  
come a little nearer this ways.  

**FALSTAFF**  
I warrant thee, nobody hears; mine own people, mine  
own people.  

**MISTRESS QUICKLY**  
Are they so? God bless them and make them his servants!  

**FALSTAFF**  
Well, Mistress Ford; what of her?  

**MISTRESS QUICKLY**  
Why, sir, she's a good creature. Lord Lord! your  
worship's a wanton! Well, heaven forgive you and all  
of us, I pray!  

**FALSTAFF**  
Mistress Ford; come, Mistress Ford,--  

**MISTRESS QUICKLY**  
Marry, this is the short and the long of it; you  
have brought her into such a canaries as 'tis  
wonderful. The best courtier of them all, when the  
court lay at Windsor, could never have brought her  
to such a canary. Yet there has been knights, and  
lords, and gentlemen, with their coaches, I warrant  
you, coach after coach, letter after letter, gift  
after gift; smelling so sweetly, all musk, and so  
rushling, I warrant you, in silk and gold; and in  
such alligant terms; and in such wine and sugar of  
the best and the fairest, that would have won any  
woman's heart; and, I warrant you, they could never  
get an eye-wink of her: I had myself twenty angels  
given me this morning; but I defy all angels, in  
any such sort, as they say, but in the way of  
honesty: and, I warrant you, they could never get  
her so much as sip on a cup with the proudest of  
them all: and yet there has been earls, nay, which  
is more, pensioners; but, I warrant you, all is one with her.  

**FALSTAFF**  
But what says she to me? be brief, my good  
she-Mercury.  

**MISTRESS QUICKLY**  
Marry, she hath received your letter, for the which  
she thanks you a thousand times; and she gives you  
to notify that her husband will be absence from his  
house between ten and eleven.  

**FALSTAFF**  
Ten and eleven?  

**MISTRESS QUICKLY**  
Ay, forsooth; and then you may come and see the  
picture, she says, that you wot of: Master Ford,  
her husband, will be from home. Alas! the sweet  
woman leads an ill life with him: he's a very  
jealousy man: she leads a very frampold life with  
him, good heart.  

**FALSTAFF**  
Ten and eleven. Woman, commend me to her; I will  
not fail her.  

**MISTRESS QUICKLY**  
Why, you say well. But I have another messenger to  
your worship. Mistress Page hath her hearty  
commendations to you too: and let me tell you in  
your ear, she's as fartuous a civil modest wife, and  
one, I tell you, that will not miss you morning nor  
evening prayer, as any is in Windsor, whoe'er be the  
other: and she bade me tell your worship that her  
husband is seldom from home; but she hopes there  
will come a time. I never knew a woman so dote upon  
a man: surely I think you have charms, la; yes, in truth.  

**FALSTAFF**  
Not I, I assure thee: setting the attractions of my  
good parts aside I have no other charms.  

**MISTRESS QUICKLY**  
Blessing on your heart for't!  

**FALSTAFF**  
But, I pray thee, tell me this: has Ford's wife and  
Page's wife acquainted each other how they love me?  

**MISTRESS QUICKLY**  
That were a jest indeed! they have not so little  
grace, I hope: that were a trick indeed! but  
Mistress Page would desire you to send her your  
little page, of all loves: her husband has a  
marvellous infection to the little page; and truly  
Master Page is an honest man. Never a wife in  
Windsor leads a better life than she does: do what  
she will, say what she will, take all, pay all, go  
to bed when she list, rise when she list, all is as  
she will: and truly she deserves it; for if there  
be a kind woman in Windsor, she is one. You must  
send her your page; no remedy.  

**FALSTAFF**  
Why, I will.  

**MISTRESS QUICKLY**  
Nay, but do so, then: and, look you, he may come and  
go between you both; and in any case have a  
nay-word, that you may know one another's mind, and  
the boy never need to understand any thing; for  
'tis not good that children should know any  
wickedness: old folks, you know, have discretion,  
as they say, and know the world.  

**FALSTAFF**  
Fare thee well: commend me to them both: there's  
my purse; I am yet thy debtor. Boy, go along with  
this woman.  

_Exeunt MISTRESS QUICKLY and ROBIN_

This news distracts me!  

**PISTOL**  
This punk is one of Cupid's carriers:  
Clap on more sails; pursue; up with your fights:  
Give fire: she is my prize, or ocean whelm them all!  

_Exit_

**FALSTAFF**  
Sayest thou so, old Jack? go thy ways; I'll make  
more of thy old body than I have done. Will they  
yet look after thee? Wilt thou, after the expense  
of so much money, be now a gainer? Good body, I  
thank thee. Let them say 'tis grossly done; so it be  
fairly done, no matter.  

_Enter BARDOLPH_

**BARDOLPH**  
Sir John, there's one Master Brook below would fain  
speak with you, and be acquainted with you; and hath  
sent your worship a morning's draught of sack.  

**FALSTAFF**  
Brook is his name?  

**BARDOLPH**  
Ay, sir.  

**FALSTAFF**  
Call him in.  

_Exit BARDOLPH_

Such Brooks are welcome to me, that o'erflow such  
liquor. Ah, ha! Mistress Ford and Mistress Page  
have I encompassed you? go to; via!  

_Re-enter BARDOLPH, with FORD disguised_

**FORD**  
Bless you, sir!  

**FALSTAFF**  
And you, sir! Would you speak with me?  

**FORD**  
I make bold to press with so little preparation upon  
you.  

**FALSTAFF**  
You're welcome. What's your will? Give us leave, drawer.  

_Exit BARDOLPH_

**FORD**  
Sir, I am a gentleman that have spent much; my name is Brook.  

**FALSTAFF**  
Good Master Brook, I desire more acquaintance of you.  

**FORD**  
Good Sir John, I sue for yours: not to charge you;  
for I must let you understand I think myself in  
better plight for a lender than you are: the which  
hath something embolden'd me to this unseasoned  
intrusion; for they say, if money go before, all  
ways do lie open.  

**FALSTAFF**  
Money is a good soldier, sir, and will on.  

**FORD**  
Troth, and I have a bag of money here troubles me:  
if you will help to bear it, Sir John, take all, or  
half, for easing me of the carriage.  

**FALSTAFF**  
Sir, I know not how I may deserve to be your porter.  

**FORD**  
I will tell you, sir, if you will give me the hearing.  

**FALSTAFF**  
Speak, good Master Brook: I shall be glad to be  
your servant.  

**FORD**  
Sir, I hear you are a scholar,--I will be brief  
with you,--and you have been a man long known to me,  
though I had never so good means, as desire, to make  
myself acquainted with you. I shall discover a  
thing to you, wherein I must very much lay open mine  
own imperfection: but, good Sir John, as you have  
one eye upon my follies, as you hear them unfolded,  
turn another into the register of your own; that I  
may pass with a reproof the easier, sith you  
yourself know how easy it is to be such an offender.  

**FALSTAFF**  
Very well, sir; proceed.  

**FORD**  
There is a gentlewoman in this town; her husband's  
name is Ford.  

**FALSTAFF**  
Well, sir.  

**FORD**  
I have long loved her, and, I protest to you,  
bestowed much on her; followed her with a doting  
observance; engrossed opportunities to meet her;  
fee'd every slight occasion that could but niggardly  
give me sight of her; not only bought many presents  
to give her, but have given largely to many to know  
what she would have given; briefly, I have pursued  
her as love hath pursued me; which hath been on the  
wing of all occasions. But whatsoever I have  
merited, either in my mind or, in my means, meed,  
I am sure, I have received none; unless experience  
be a jewel that I have purchased at an infinite  
rate, and that hath taught me to say this:  
'Love like a shadow flies when substance love pursues;  
Pursuing that that flies, and flying what pursues.'  

**FALSTAFF**  
Have you received no promise of satisfaction at her hands?  

**FORD**  
Never.  

**FALSTAFF**  
Have you importuned her to such a purpose?  

**FORD**  
Never.  

**FALSTAFF**  
Of what quality was your love, then?  

**FORD**  
Like a fair house built on another man's ground; so  
that I have lost my edifice by mistaking the place  
where I erected it.  

**FALSTAFF**  
To what purpose have you unfolded this to me?  

**FORD**  
When I have told you that, I have told you all.  
Some say, that though she appear honest to me, yet in  
other places she enlargeth her mirth so far that  
there is shrewd construction made of her. Now, Sir  
John, here is the heart of my purpose: you are a  
gentleman of excellent breeding, admirable  
discourse, of great admittance, authentic in your  
place and person, generally allowed for your many  
war-like, court-like, and learned preparations.  

**FALSTAFF**  
O, sir!  

**FORD**  
Believe it, for you know it. There is money; spend  
it, spend it; spend more; spend all I have; only  
give me so much of your time in exchange of it, as  
to lay an amiable siege to the honesty of this  
Ford's wife: use your art of wooing; win her to  
consent to you: if any man may, you may as soon as  
any.  

**FALSTAFF**  
Would it apply well to the vehemency of your  
affection, that I should win what you would enjoy?  
Methinks you prescribe to yourself very preposterously.  

**FORD**  
O, understand my drift. She dwells so securely on  
the excellency of her honour, that the folly of my  
soul dares not present itself: she is too bright to  
be looked against. Now, could I could come to her  
with any detection in my hand, my desires had  
instance and argument to commend themselves: I  
could drive her then from the ward of her purity,  
her reputation, her marriage-vow, and a thousand  
other her defences, which now are too too strongly  
embattled against me. What say you to't, Sir John?  

**FALSTAFF**  
Master Brook, I will first make bold with your  
money; next, give me your hand; and last, as I am a  
gentleman, you shall, if you will, enjoy Ford's wife.  

**FORD**  
O good sir!  

**FALSTAFF**  
I say you shall.  

**FORD**  
Want no money, Sir John; you shall want none.  

**FALSTAFF**  
Want no Mistress Ford, Master Brook; you shall want  
none. I shall be with her, I may tell you, by her  
own appointment; even as you came in to me, her  
assistant or go-between parted from me: I say I  
shall be with her between ten and eleven; for at  
that time the jealous rascally knave her husband  
will be forth. Come you to me at night; you shall  
know how I speed.  

**FORD**  
I am blest in your acquaintance. Do you know Ford,  
sir?  

**FALSTAFF**  
Hang him, poor cuckoldly knave! I know him not:  
yet I wrong him to call him poor; they say the  
jealous wittolly knave hath masses of money; for the  
which his wife seems to me well-favored. I will  
use her as the key of the cuckoldly rogue's coffer;  
and there's my harvest-home.  

**FORD**  
I would you knew Ford, sir, that you might avoid him  
if you saw him.  

**FALSTAFF**  
Hang him, mechanical salt-butter rogue! I will  
stare him out of his wits; I will awe him with my  
cudgel: it shall hang like a meteor o'er the  
cuckold's horns. Master Brook, thou shalt know I  
will predominate over the peasant, and thou shalt  
lie with his wife. Come to me soon at night.  
Ford's a knave, and I will aggravate his style;  
thou, Master Brook, shalt know him for knave and  
cuckold. Come to me soon at night.  

_Exit_

**FORD**  
What a damned Epicurean rascal is this! My heart is  
ready to crack with impatience. Who says this is  
improvident jealousy? my wife hath sent to him; the  
hour is fixed; the match is made. Would any man  
have thought this? See the hell of having a false  
woman! My bed shall be abused, my coffers  
ransacked, my reputation gnawn at; and I shall not  
only receive this villanous wrong, but stand under  
the adoption of abominable terms, and by him that  
does me this wrong. Terms! names! Amaimon sounds  
well; Lucifer, well; Barbason, well; yet they are  
devils' additions, the names of fiends: but  
Cuckold! Wittol!--Cuckold! the devil himself hath  
not such a name. Page is an ass, a secure ass: he  
will trust his wife; he will not be jealous. I will  
rather trust a Fleming with my butter, Parson Hugh  
the Welshman with my cheese, an Irishman with my  
aqua-vitae bottle, or a thief to walk my ambling  
gelding, than my wife with herself; then she plots,  
then she ruminates, then she devises; and what they  
think in their hearts they may effect, they will  
break their hearts but they will effect. God be  
praised for my jealousy! Eleven o'clock the hour.  
I will prevent this, detect my wife, be revenged on  
Falstaff, and laugh at Page. I will about it;  
better three hours too soon than a minute too late.  
Fie, fie, fie! cuckold! cuckold! cuckold!  

_Exit_

### SCENE III. A field near Windsor.

_Enter DOCTOR CAIUS and RUGBY_

**DOCTOR CAIUS**  
Jack Rugby!  

**RUGBY**  
Sir?  

**DOCTOR CAIUS**  
Vat is de clock, Jack?  

**RUGBY**  
'Tis past the hour, sir, that Sir Hugh promised to meet.  

**DOCTOR CAIUS**  
By gar, he has save his soul, dat he is no come; he  
has pray his Pible well, dat he is no come: by gar,  
Jack Rugby, he is dead already, if he be come.  

**RUGBY**  
He is wise, sir; he knew your worship would kill  
him, if he came.  

**DOCTOR CAIUS**  
By gar, de herring is no dead so as I vill kill him.  
Take your rapier, Jack; I vill tell you how I vill kill him.  

**RUGBY**  
Alas, sir, I cannot fence.  

**DOCTOR CAIUS**  
Villany, take your rapier.  

**RUGBY**  
Forbear; here's company.  

_Enter Host, SHALLOW, SLENDER, and PAGE_

**Host**  
Bless thee, bully doctor!  

**SHALLOW**  
Save you, Master Doctor Caius!  

**PAGE**  
Now, good master doctor!  

**SLENDER**  
Give you good morrow, sir.  

**DOCTOR CAIUS**  
Vat be all you, one, two, tree, four, come for?  

**Host**  
To see thee fight, to see thee foin, to see thee  
traverse; to see thee here, to see thee there; to  
see thee pass thy punto, thy stock, thy reverse, thy  
distance, thy montant. Is he dead, my Ethiopian? is  
he dead, my Francisco? ha, bully! What says my  
AEsculapius? my Galen? my heart of elder? ha! is  
he dead, bully stale? is he dead?  

**DOCTOR CAIUS**  
By gar, he is de coward Jack priest of de vorld; he  
is not show his face.  

**Host**  
Thou art a Castalion-King-Urinal. Hector of Greece, my boy!  

**DOCTOR CAIUS**  
I pray you, bear vitness that me have stay six or  
seven, two, tree hours for him, and he is no come.  

**SHALLOW**  
He is the wiser man, master doctor: he is a curer of  
souls, and you a curer of bodies; if you should  
fight, you go against the hair of your professions.  
Is it not true, Master Page?  

**PAGE**  
Master Shallow, you have yourself been a great  
fighter, though now a man of peace.  

**SHALLOW**  
Bodykins, Master Page, though I now be old and of  
the peace, if I see a sword out, my finger itches to  
make one. Though we are justices and doctors and  
churchmen, Master Page, we have some salt of our  
youth in us; we are the sons of women, Master Page.  

**PAGE**  
'Tis true, Master Shallow.  

**SHALLOW**  
It will be found so, Master Page. Master Doctor  
Caius, I am come to fetch you home. I am sworn of  
the peace: you have showed yourself a wise  
physician, and Sir Hugh hath shown himself a wise  
and patient churchman. You must go with me, master doctor.  

**Host**  
Pardon, guest-justice. A word, Mounseur Mockwater.  

**DOCTOR CAIUS**  
Mock-vater! vat is dat?  

**Host**  
Mock-water, in our English tongue, is valour, bully.  

**DOCTOR CAIUS**  
By gar, den, I have as mush mock-vater as de  
Englishman. Scurvy jack-dog priest! by gar, me  
vill cut his ears.  

**Host**  
He will clapper-claw thee tightly, bully.  

**DOCTOR CAIUS**  
Clapper-de-claw! vat is dat?  

**Host**  
That is, he will make thee amends.  

**DOCTOR CAIUS**  
By gar, me do look he shall clapper-de-claw me;  
for, by gar, me vill have it.  

**Host**  
And I will provoke him to't, or let him wag.  

**DOCTOR CAIUS**  
Me tank you for dat.  

**Host**  
And, moreover, bully,--but first, master guest, and  
Master Page, and eke Cavaleiro Slender, go you  
through the town to Frogmore.  

_Aside to them_

**PAGE**  
Sir Hugh is there, is he?  

**Host**  
He is there: see what humour he is in; and I will  
bring the doctor about by the fields. Will it do well?  

**SHALLOW**  
We will do it.  

**PAGE** **SHALLOW** **SLENDER**  
Adieu, good master doctor.  

_Exeunt PAGE, SHALLOW, and SLENDER_

**DOCTOR CAIUS**  
By gar, me vill kill de priest; for he speak for a  
jack-an-ape to Anne Page.  

**Host**  
Let him die: sheathe thy impatience, throw cold  
water on thy choler: go about the fields with me  
through Frogmore: I will bring thee where Mistress  
Anne Page is, at a farm-house a-feasting; and thou  
shalt woo her. Cried I aim? said I well?  

**DOCTOR CAIUS**  
By gar, me dank you for dat: by gar, I love you;  
and I shall procure-a you de good guest, de earl,  
de knight, de lords, de gentlemen, my patients.  

**Host**  
For the which I will be thy adversary toward Anne  
Page. Said I well?  

**DOCTOR CAIUS**  
By gar, 'tis good; vell said.  

**Host**  
Let us wag, then.  

**DOCTOR CAIUS**  
Come at my heels, Jack Rugby.  

_Exeunt_

# ACT III

### SCENE I. A field near Frogmore.

_Enter SIR HUGH EVANS and SIMPLE_

**SIR HUGH EVANS**  
I pray you now, good master Slender's serving-man,  
and friend Simple by your name, which way have you  
looked for Master Caius, that calls himself doctor of physic?  

**SIMPLE**  
Marry, sir, the pittie-ward, the park-ward, every  
way; old Windsor way, and every way but the town  
way.  

**SIR HUGH EVANS**  
I most fehemently desire you you will also look that  
way.  

**SIMPLE**  
I will, sir.  

_Exit_

**SIR HUGH EVANS**  
'Pless my soul, how full of chollors I am, and  
trempling of mind! I shall be glad if he have  
deceived me. How melancholies I am! I will knog  
his urinals about his knave's costard when I have  
good opportunities for the ork. 'Pless my soul!  

_Sings_

To shallow rivers, to whose falls  
Melodious birds sings madrigals;  
There will we make our peds of roses,  
And a thousand fragrant posies.  
To shallow--  
Mercy on me! I have a great dispositions to cry.  

_Sings_

Melodious birds sing madrigals--  
When as I sat in Pabylon--  
And a thousand vagram posies.  
To shallow & c.  

_Re-enter SIMPLE_

**SIMPLE**  
Yonder he is coming, this way, Sir Hugh.  

**SIR HUGH EVANS**  
He's welcome.  

_Sings_

To shallow rivers, to whose falls-  
Heaven prosper the right! What weapons is he?  

**SIMPLE**  
No weapons, sir. There comes my master, Master  
Shallow, and another gentleman, from Frogmore, over  
the stile, this way.  

**SIR HUGH EVANS**  
Pray you, give me my gown; or else keep it in your arms.  

_Enter PAGE, SHALLOW, and SLENDER_

**SHALLOW**  
How now, master Parson! Good morrow, good Sir Hugh.  
Keep a gamester from the dice, and a good student  
from his book, and it is wonderful.  

**SLENDER**  
[Aside]_  
Ah, sweet Anne Page!  

**PAGE**  
'Save you, good Sir Hugh!  

**SIR HUGH EVANS**  
'Pless you from his mercy sake, all of you!  

**SHALLOW**  
What, the sword and the word! do you study them  
both, master parson?  

**PAGE**  
And youthful still! in your doublet and hose this  
raw rheumatic day!  

**SIR HUGH EVANS**  
There is reasons and causes for it.  

**PAGE**  
We are come to you to do a good office, master parson.  

**SIR HUGH EVANS**  
Fery well: what is it?  

**PAGE**  
Yonder is a most reverend gentleman, who, belike  
having received wrong by some person, is at most  
odds with his own gravity and patience that ever you  
saw.  

**SHALLOW**  
I have lived fourscore years and upward; I never  
heard a man of his place, gravity and learning, so  
wide of his own respect.  

**SIR HUGH EVANS**  
What is he?  

**PAGE**  
I think you know him; Master Doctor Caius, the  
renowned French physician.  

**SIR HUGH EVANS**  
Got's will, and his passion of my heart! I had as  
lief you would tell me of a mess of porridge.  

**PAGE**  
Why?  

**SIR HUGH EVANS**  
He has no more knowledge in Hibocrates and Galen,  
\--and he is a knave besides; a cowardly knave as you  
would desires to be acquainted withal.  

**PAGE**  
I warrant you, he's the man should fight with him.  

**SHALLOW**  
[Aside]_  
O sweet Anne Page!  

**SHALLOW**  
It appears so by his weapons. Keep them asunder:  
here comes Doctor Caius.  

_Enter Host, DOCTOR CAIUS, and RUGBY_

**PAGE**  
Nay, good master parson, keep in your weapon.  

**SHALLOW**  
So do you, good master doctor.  

**Host**  
Disarm them, and let them question: let them keep  
their limbs whole and hack our English.  

**DOCTOR CAIUS**  
I pray you, let-a me speak a word with your ear.  
Vherefore vill you not meet-a me?  

**SIR HUGH EVANS**  
[Aside to DOCTOR CAIUS]_  
Pray you, use your patience:  
in good time.  

**DOCTOR CAIUS**  
By gar, you are de coward, de Jack dog, John ape.  

**SIR HUGH EVANS**  
[Aside to DOCTOR CAIUS]_  
Pray you let us not be  
laughing-stocks to other men's humours; I desire you  
in friendship, and I will one way or other make you amends.  

_Aloud_

I will knog your urinals about your knave's cockscomb  
for missing your meetings and appointments.  

**DOCTOR CAIUS**  
Diable! Jack Rugby,--mine host de Jarteer,--have I  
not stay for him to kill him? have I not, at de place  
I did appoint?  

**SIR HUGH EVANS**  
As I am a Christians soul now, look you, this is the  
place appointed: I'll be judgement by mine host of  
the Garter.  

**Host**  
Peace, I say, Gallia and Gaul, French and Welsh,  
soul-curer and body-curer!  

**DOCTOR CAIUS**  
Ay, dat is very good; excellent.  

**Host**  
Peace, I say! hear mine host of the Garter. Am I  
politic? am I subtle? am I a Machiavel? Shall I  
lose my doctor? no; he gives me the potions and the  
motions. Shall I lose my parson, my priest, my Sir  
Hugh? no; he gives me the proverbs and the  
no-verbs. Give me thy hand, terrestrial; so. Give me  
thy hand, celestial; so. Boys of art, I have  
deceived you both; I have directed you to wrong  
places: your hearts are mighty, your skins are  
whole, and let burnt sack be the issue. Come, lay  
their swords to pawn. Follow me, lads of peace;  
follow, follow, follow.  

**SHALLOW**  
Trust me, a mad host. Follow, gentlemen, follow.  

**SLENDER**  
[Aside]_  
O sweet Anne Page!  

_Exeunt SHALLOW, SLENDER, PAGE, and Host_

**DOCTOR CAIUS**  
Ha, do I perceive dat? have you make-a de sot of  
us, ha, ha?  

**SIR HUGH EVANS**  
This is well; he has made us his vlouting-stog. I  
desire you that we may be friends; and let us knog  
our prains together to be revenge on this same  
scall, scurvy cogging companion, the host of the Garter.  

**DOCTOR CAIUS**  
By gar, with all my heart. He promise to bring me  
where is Anne Page; by gar, he deceive me too.  

**SIR HUGH EVANS**  
Well, I will smite his noddles. Pray you, follow.  

_Exeunt_

### SCENE II. A street.

_Enter MISTRESS PAGE and ROBIN_

**MISTRESS PAGE**  
Nay, keep your way, little gallant; you were wont to  
be a follower, but now you are a leader. Whether  
had you rather lead mine eyes, or eye your master's heels?  

**ROBIN**  
I had rather, forsooth, go before you like a man  
than follow him like a dwarf.  

**MISTRESS PAGE**  
O, you are a flattering boy: now I see you'll be a courtier.  

_Enter FORD_

**FORD**  
Well met, Mistress Page. Whither go you?  

**MISTRESS PAGE**  
Truly, sir, to see your wife. Is she at home?  

**FORD**  
Ay; and as idle as she may hang together, for want  
of company. I think, if your husbands were dead,  
you two would marry.  

**MISTRESS PAGE**  
Be sure of that,--two other husbands.  

**FORD**  
Where had you this pretty weather-cock?  

**MISTRESS PAGE**  
I cannot tell what the dickens his name is my  
husband had him of. What do you call your knight's  
name, sirrah?  

**ROBIN**  
Sir John Falstaff.  

**FORD**  
Sir John Falstaff!  

**MISTRESS PAGE**  
He, he; I can never hit on's name. There is such a  
league between my good man and he! Is your wife at  
home indeed?  

**FORD**  
Indeed she is.  

**MISTRESS PAGE**  
By your leave, sir: I am sick till I see her.  

_Exeunt MISTRESS PAGE and ROBIN_

**FORD**  
Has Page any brains? hath he any eyes? hath he any  
thinking? Sure, they sleep; he hath no use of them.  
Why, this boy will carry a letter twenty mile, as  
easy as a cannon will shoot point-blank twelve  
score. He pieces out his wife's inclination; he  
gives her folly motion and advantage: and now she's  
going to my wife, and Falstaff's boy with her. A  
man may hear this shower sing in the wind. And  
Falstaff's boy with her! Good plots, they are laid;  
and our revolted wives share damnation together.  
Well; I will take him, then torture my wife, pluck  
the borrowed veil of modesty from the so seeming  
Mistress Page, divulge Page himself for a secure and  
wilful Actaeon; and to these violent proceedings all  
my neighbours shall cry aim.  

_Clock heard_

The clock gives me my cue, and my assurance bids me  
search: there I shall find Falstaff: I shall be  
rather praised for this than mocked; for it is as  
positive as the earth is firm that Falstaff is  
there: I will go.  

_Enter PAGE, SHALLOW, SLENDER, Host, SIR HUGH EVANS, DOCTOR CAIUS, and
RUGBY_

**SHALLOW** **PAGE** **& C**  
Well met, Master Ford.  

**FORD**  
Trust me, a good knot: I have good cheer at home;  
and I pray you all go with me.  

**SHALLOW**  
I must excuse myself, Master Ford.  

**SLENDER**  
And so must I, sir: we have appointed to dine with  
Mistress Anne, and I would not break with her for  
more money than I'll speak of.  

**SHALLOW**  
We have lingered about a match between Anne Page and  
my cousin Slender, and this day we shall have our answer.  

**SLENDER**  
I hope I have your good will, father Page.  

**PAGE**  
You have, Master Slender; I stand wholly for you:  
but my wife, master doctor, is for you altogether.  

**DOCTOR CAIUS**  
Ay, be-gar; and de maid is love-a me: my nursh-a  
Quickly tell me so mush.  

**Host**  
What say you to young Master Fenton? he capers, he  
dances, he has eyes of youth, he writes verses, he  
speaks holiday, he smells April and May: he will  
carry't, he will carry't; 'tis in his buttons; he  
will carry't.  

**PAGE**  
Not by my consent, I promise you. The gentleman is  
of no having: he kept company with the wild prince  
and Poins; he is of too high a region; he knows too  
much. No, he shall not knit a knot in his fortunes  
with the finger of my substance: if he take her,  
let him take her simply; the wealth I have waits on  
my consent, and my consent goes not that way.  

**FORD**  
I beseech you heartily, some of you go home with me  
to dinner: besides your cheer, you shall have  
sport; I will show you a monster. Master doctor,  
you shall go; so shall you, Master Page; and you, Sir Hugh.  

**SHALLOW**  
Well, fare you well: we shall have the freer wooing  
at Master Page's.  

_Exeunt SHALLOW, and SLENDER_

**DOCTOR CAIUS**  
Go home, John Rugby; I come anon.  

_Exit RUGBY_

**Host**  
Farewell, my hearts: I will to my honest knight  
Falstaff, and drink canary with him.  

_Exit_

**FORD**  
[Aside]_  
I think I shall drink in pipe wine first  
with him; I'll make him dance. Will you go, gentles?  

**All**  
Have with you to see this monster.  

_Exeunt_

### SCENE III. A room in FORD'S house.

_Enter MISTRESS FORD and MISTRESS PAGE_

**MISTRESS FORD**  
What, John! What, Robert!  

**MISTRESS PAGE**  
Quickly, quickly! is the buck-basket--  

**MISTRESS FORD**  
I warrant. What, Robin, I say!  

_Enter Servants with a basket_

**MISTRESS PAGE**  
Come, come, come.  

**MISTRESS FORD**  
Here, set it down.  

**MISTRESS PAGE**  
Give your men the charge; we must be brief.  

**MISTRESS FORD**  
Marry, as I told you before, John and Robert, be  
ready here hard by in the brew-house: and when I  
suddenly call you, come forth, and without any pause  
or staggering take this basket on your shoulders:  
that done, trudge with it in all haste, and carry  
it among the whitsters in Datchet-mead, and there  
empty it in the muddy ditch close by the Thames side.  

**MISTRESS PAGE**  
You will do it?  

**MISTRESS FORD**  
I ha' told them over and over; they lack no  
direction. Be gone, and come when you are called.  

_Exeunt Servants_

**MISTRESS PAGE**  
Here comes little Robin.  

_Enter ROBIN_

**MISTRESS FORD**  
How now, my eyas-musket! what news with you?  

**ROBIN**  
My master, Sir John, is come in at your back-door,  
Mistress Ford, and requests your company.  

**MISTRESS PAGE**  
You little Jack-a-Lent, have you been true to us?  

**ROBIN**  
Ay, I'll be sworn. My master knows not of your  
being here and hath threatened to put me into  
everlasting liberty if I tell you of it; for he  
swears he'll turn me away.  

**MISTRESS PAGE**  
Thou'rt a good boy: this secrecy of thine shall be  
a tailor to thee and shall make thee a new doublet  
and hose. I'll go hide me.  

**MISTRESS FORD**  
Do so. Go tell thy master I am alone.  

_Exit ROBIN_

Mistress Page, remember you your cue.  

**MISTRESS PAGE**  
I warrant thee; if I do not act it, hiss me.  

_Exit_

**MISTRESS FORD**  
Go to, then: we'll use this unwholesome humidity,  
this gross watery pumpion; we'll teach him to know  
turtles from jays.  

_Enter FALSTAFF_

**FALSTAFF**  
Have I caught thee, my heavenly jewel? Why, now let  
me die, for I have lived long enough: this is the  
period of my ambition: O this blessed hour!  

**MISTRESS FORD**  
O sweet Sir John!  

**FALSTAFF**  
Mistress Ford, I cannot cog, I cannot prate,  
Mistress Ford. Now shall I sin in my wish: I would  
thy husband were dead: I'll speak it before the  
best lord; I would make thee my lady.  

**MISTRESS FORD**  
I your lady, Sir John! alas, I should be a pitiful lady!  

**FALSTAFF**  
Let the court of France show me such another. I see  
how thine eye would emulate the diamond: thou hast  
the right arched beauty of the brow that becomes the  
ship-tire, the tire-valiant, or any tire of  
Venetian admittance.  

**MISTRESS FORD**  
A plain kerchief, Sir John: my brows become nothing  
else; nor that well neither.  

**FALSTAFF**  
By the Lord, thou art a traitor to say so: thou  
wouldst make an absolute courtier; and the firm  
fixture of thy foot would give an excellent motion  
to thy gait in a semi-circled farthingale. I see  
what thou wert, if Fortune thy foe were not, Nature  
thy friend. Come, thou canst not hide it.  

**MISTRESS FORD**  
Believe me, there is no such thing in me.  

**FALSTAFF**  
What made me love thee? let that persuade thee  
there's something extraordinary in thee. Come, I  
cannot cog and say thou art this and that, like a  
many of these lisping hawthorn-buds, that come like  
women in men's apparel, and smell like Bucklersbury  
in simple time; I cannot: but I love thee; none  
but thee; and thou deservest it.  

**MISTRESS FORD**  
Do not betray me, sir. I fear you love Mistress Page.  

**FALSTAFF**  
Thou mightst as well say I love to walk by the  
Counter-gate, which is as hateful to me as the reek  
of a lime-kiln.  

**MISTRESS FORD**  
Well, heaven knows how I love you; and you shall one  
day find it.  

**FALSTAFF**  
Keep in that mind; I'll deserve it.  

**MISTRESS FORD**  
Nay, I must tell you, so you do; or else I could not  
be in that mind.  

**ROBIN**  
[Within]_  
Mistress Ford, Mistress Ford! here's  
Mistress Page at the door, sweating and blowing and  
looking wildly, and would needs speak with you presently.  

**FALSTAFF**  
She shall not see me: I will ensconce me behind the arras.  

**MISTRESS FORD**  
Pray you, do so: she's a very tattling woman.  

_FALSTAFF hides himself_

_Re-enter MISTRESS PAGE and ROBIN_

What's the matter? how now!  

**MISTRESS PAGE**  
O Mistress Ford, what have you done? You're shamed,  
you're overthrown, you're undone for ever!  

**MISTRESS FORD**  
What's the matter, good Mistress Page?  

**MISTRESS PAGE**  
O well-a-day, Mistress Ford! having an honest man  
to your husband, to give him such cause of suspicion!  

**MISTRESS FORD**  
What cause of suspicion?  

**MISTRESS PAGE**  
What cause of suspicion! Out pon you! how am I  
mistook in you!  

**MISTRESS FORD**  
Why, alas, what's the matter?  

**MISTRESS PAGE**  
Your husband's coming hither, woman, with all the  
officers in Windsor, to search for a gentleman that  
he says is here now in the house by your consent, to  
take an ill advantage of his assence: you are undone.  

**MISTRESS FORD**  
'Tis not so, I hope.  

**MISTRESS PAGE**  
Pray heaven it be not so, that you have such a man  
here! but 'tis most certain your husband's coming,  
with half Windsor at his heels, to search for such a  
one. I come before to tell you. If you know  
yourself clear, why, I am glad of it; but if you  
have a friend here convey, convey him out. Be not  
amazed; call all your senses to you; defend your  
reputation, or bid farewell to your good life for ever.  

**MISTRESS FORD**  
What shall I do? There is a gentleman my dear  
friend; and I fear not mine own shame so much as his  
peril: I had rather than a thousand pound he were  
out of the house.  

**MISTRESS PAGE**  
For shame! never stand 'you had rather' and 'you  
had rather:' your husband's here at hand, bethink  
you of some conveyance: in the house you cannot  
hide him. O, how have you deceived me! Look, here  
is a basket: if he be of any reasonable stature, he  
may creep in here; and throw foul linen upon him, as  
if it were going to bucking: or--it is whiting-time  
\--send him by your two men to Datchet-mead.  

**MISTRESS FORD**  
He's too big to go in there. What shall I do?  

**FALSTAFF**  
[Coming forward]_  
Let me see't, let me see't, O, let  
me see't! I'll in, I'll in. Follow your friend's  
counsel. I'll in.  

**MISTRESS PAGE**  
What, Sir John Falstaff! Are these your letters, knight?  

**FALSTAFF**  
I love thee. Help me away. Let me creep in here.  
I'll never--  

_Gets into the basket; they cover him with foul linen_

**MISTRESS PAGE**  
Help to cover your master, boy. Call your men,  
Mistress Ford. You dissembling knight!  

**MISTRESS FORD**  
What, John! Robert! John!  

_Exit ROBIN_

_Re-enter Servants_

Go take up these clothes here quickly. Where's the  
cowl-staff? look, how you drumble! Carry them to  
the laundress in Datchet-meat; quickly, come.  

_Enter FORD, PAGE, DOCTOR CAIUS, and SIR HUGH EVANS_

**FORD**  
Pray you, come near: if I suspect without cause,  
why then make sport at me; then let me be your jest;  
I deserve it. How now! whither bear you this?  

**Servant**  
To the laundress, forsooth.  

**MISTRESS FORD**  
Why, what have you to do whither they bear it? You  
were best meddle with buck-washing.  

**FORD**  
Buck! I would I could wash myself of the buck!  
Buck, buck, buck! Ay, buck; I warrant you, buck;  
and of the season too, it shall appear.  

_Exeunt Servants with the basket_

Gentlemen, I have dreamed to-night; I'll tell you my  
dream. Here, here, here be my keys: ascend my  
chambers; search, seek, find out: I'll warrant  
we'll unkennel the fox. Let me stop this way first.  

_Locking the door_

So, now uncape.  

**PAGE**  
Good Master Ford, be contented: you wrong yourself too much.  

**FORD**  
True, Master Page. Up, gentlemen: you shall see  
sport anon: follow me, gentlemen.  

_Exit_

**SIR HUGH EVANS**  
This is fery fantastical humours and jealousies.  

**DOCTOR CAIUS**  
By gar, 'tis no the fashion of France; it is not  
jealous in France.  

**PAGE**  
Nay, follow him, gentlemen; see the issue of his search.  

_Exeunt PAGE, DOCTOR CAIUS, and SIR HUGH EVANS_

**MISTRESS PAGE**  
Is there not a double excellency in this?  

**MISTRESS FORD**  
I know not which pleases me better, that my husband  
is deceived, or Sir John.  

**MISTRESS PAGE**  
What a taking was he in when your husband asked who  
was in the basket!  

**MISTRESS FORD**  
I am half afraid he will have need of washing; so  
throwing him into the water will do him a benefit.  

**MISTRESS PAGE**  
Hang him, dishonest rascal! I would all of the same  
strain were in the same distress.  

**MISTRESS FORD**  
I think my husband hath some special suspicion of  
Falstaff's being here; for I never saw him so gross  
in his jealousy till now.  

**MISTRESS PAGE**  
I will lay a plot to try that; and we will yet have  
more tricks with Falstaff: his dissolute disease will  
scarce obey this medicine.  

**MISTRESS FORD**  
Shall we send that foolish carrion, Mistress  
Quickly, to him, and excuse his throwing into the  
water; and give him another hope, to betray him to  
another punishment?  

**MISTRESS PAGE**  
We will do it: let him be sent for to-morrow,  
eight o'clock, to have amends.  

_Re-enter FORD, PAGE, DOCTOR CAIUS, and SIR HUGH EVANS_

**FORD**  
I cannot find him: may be the knave bragged of that  
he could not compass.  

**MISTRESS PAGE**  
[Aside to MISTRESS FORD]_  
Heard you that?  

**MISTRESS FORD**  
You use me well, Master Ford, do you?  

**FORD**  
Ay, I do so.  

**MISTRESS FORD**  
Heaven make you better than your thoughts!  

**FORD**  
Amen!  

**MISTRESS PAGE**  
You do yourself mighty wrong, Master Ford.  

**FORD**  
Ay, ay; I must bear it.  

**SIR HUGH EVANS**  
If there be any pody in the house, and in the  
chambers, and in the coffers, and in the presses,  
heaven forgive my sins at the day of judgment!  

**DOCTOR CAIUS**  
By gar, nor I too: there is no bodies.  

**PAGE**  
Fie, fie, Master Ford! are you not ashamed? What  
spirit, what devil suggests this imagination? I  
would not ha' your distemper in this kind for the  
wealth of Windsor Castle.  

**FORD**  
'Tis my fault, Master Page: I suffer for it.  

**SIR HUGH EVANS**  
You suffer for a pad conscience: your wife is as  
honest a 'omans as I will desires among five  
thousand, and five hundred too.  

**DOCTOR CAIUS**  
By gar, I see 'tis an honest woman.  

**FORD**  
Well, I promised you a dinner. Come, come, walk in  
the Park: I pray you, pardon me; I will hereafter  
make known to you why I have done this. Come,  
wife; come, Mistress Page. I pray you, pardon me;  
pray heartily, pardon me.  

**PAGE**  
Let's go in, gentlemen; but, trust me, we'll mock  
him. I do invite you to-morrow morning to my house  
to breakfast: after, we'll a-birding together; I  
have a fine hawk for the bush. Shall it be so?  

**FORD**  
Any thing.  

**SIR HUGH EVANS**  
If there is one, I shall make two in the company.  

**DOCTOR CAIUS**  
If dere be one or two, I shall make-a the turd.  

**FORD**  
Pray you, go, Master Page.  

**SIR HUGH EVANS**  
I pray you now, remembrance tomorrow on the lousy  
knave, mine host.  

**DOCTOR CAIUS**  
Dat is good; by gar, with all my heart!  

**SIR HUGH EVANS**  
A lousy knave, to have his gibes and his mockeries!  

_Exeunt_

### SCENE IV. A room in PAGE'S house.

_Enter FENTON and ANNE PAGE_

**FENTON**  
I see I cannot get thy father's love;  
Therefore no more turn me to him, sweet Nan.  

**ANNE PAGE**  
Alas, how then?  

**FENTON**  
Why, thou must be thyself.  
He doth object I am too great of birth--,  
And that, my state being gall'd with my expense,  
I seek to heal it only by his wealth:  
Besides these, other bars he lays before me,  
My riots past, my wild societies;  
And tells me 'tis a thing impossible  
I should love thee but as a property.  

**ANNE PAGE**  
May be he tells you true.  

**FENTON**  
No, heaven so speed me in my time to come!  
Albeit I will confess thy father's wealth  
Was the first motive that I woo'd thee, Anne:  
Yet, wooing thee, I found thee of more value  
Than stamps in gold or sums in sealed bags;  
And 'tis the very riches of thyself  
That now I aim at.  

**ANNE PAGE**  
Gentle Master Fenton,  
Yet seek my father's love; still seek it, sir:  
If opportunity and humblest suit  
Cannot attain it, why, then,--hark you hither!  

_They converse apart_

_Enter SHALLOW, SLENDER, and MISTRESS QUICKLY_

**SHALLOW**  
Break their talk, Mistress Quickly: my kinsman shall  
speak for himself.  

**SLENDER**  
I'll make a shaft or a bolt on't: 'slid, 'tis but  
venturing.  

**SHALLOW**  
Be not dismayed.  

**SLENDER**  
No, she shall not dismay me: I care not for that,  
but that I am afeard.  

**MISTRESS QUICKLY**  
Hark ye; Master Slender would speak a word with you.  

**ANNE PAGE**  
I come to him.  

_[Aside]_  
This is my father's choice.  
O, what a world of vile ill-favor'd faults  
Looks handsome in three hundred pounds a-year!  

**MISTRESS QUICKLY**  
And how does good Master Fenton? Pray you, a word with you.  

**SHALLOW**  
She's coming; to her, coz. O boy, thou hadst a father!  

**SLENDER**  
I had a father, Mistress Anne; my uncle can tell you  
good jests of him. Pray you, uncle, tell Mistress  
Anne the jest, how my father stole two geese out of  
a pen, good uncle.  

**SHALLOW**  
Mistress Anne, my cousin loves you.  

**SLENDER**  
Ay, that I do; as well as I love any woman in  
Gloucestershire.  

**SHALLOW**  
He will maintain you like a gentlewoman.  

**SLENDER**  
Ay, that I will, come cut and long-tail, under the  
degree of a squire.  

**SHALLOW**  
He will make you a hundred and fifty pounds jointure.  

**ANNE PAGE**  
Good Master Shallow, let him woo for himself.  

**SHALLOW**  
Marry, I thank you for it; I thank you for that good  
comfort. She calls you, coz: I'll leave you.  

**ANNE PAGE**  
Now, Master Slender,--  

**SLENDER**  
Now, good Mistress Anne,--  

**ANNE PAGE**  
What is your will?  

**SLENDER**  
My will! 'od's heartlings, that's a pretty jest  
indeed! I ne'er made my will yet, I thank heaven; I  
am not such a sickly creature, I give heaven praise.  

**ANNE PAGE**  
I mean, Master Slender, what would you with me?  

**SLENDER**  
Truly, for mine own part, I would little or nothing  
with you. Your father and my uncle hath made  
motions: if it be my luck, so; if not, happy man be  
his dole! They can tell you how things go better  
than I can: you may ask your father; here he comes.  

_Enter PAGE and MISTRESS PAGE_

**PAGE**  
Now, Master Slender: love him, daughter Anne.  
Why, how now! what does Master Fenton here?  
You wrong me, sir, thus still to haunt my house:  
I told you, sir, my daughter is disposed of.  

**FENTON**  
Nay, Master Page, be not impatient.  

**MISTRESS PAGE**  
Good Master Fenton, come not to my child.  

**PAGE**  
She is no match for you.  

**FENTON**  
Sir, will you hear me?  

**PAGE**  
No, good Master Fenton.  
Come, Master Shallow; come, son Slender, in.  
Knowing my mind, you wrong me, Master Fenton.  

_Exeunt PAGE, SHALLOW, and SLENDER_

**MISTRESS QUICKLY**  
Speak to Mistress Page.  

**FENTON**  
Good Mistress Page, for that I love your daughter  
In such a righteous fashion as I do,  
Perforce, against all cheques, rebukes and manners,  
I must advance the colours of my love  
And not retire: let me have your good will.  

**ANNE PAGE**  
Good mother, do not marry me to yond fool.  

**MISTRESS PAGE**  
I mean it not; I seek you a better husband.  

**MISTRESS QUICKLY**  
That's my master, master doctor.  

**ANNE PAGE**  
Alas, I had rather be set quick i' the earth  
And bowl'd to death with turnips!  

**MISTRESS PAGE**  
Come, trouble not yourself. Good Master Fenton,  
I will not be your friend nor enemy:  
My daughter will I question how she loves you,  
And as I find her, so am I affected.  
Till then farewell, sir: she must needs go in;  
Her father will be angry.  

**FENTON**  
Farewell, gentle mistress: farewell, Nan.  

_Exeunt MISTRESS PAGE and ANNE PAGE_

**MISTRESS QUICKLY**  
This is my doing, now: 'Nay,' said I, 'will you cast  
away your child on a fool, and a physician? Look on  
Master Fenton:' this is my doing.  

**FENTON**  
I thank thee; and I pray thee, once to-night  
Give my sweet Nan this ring: there's for thy pains.  

**MISTRESS QUICKLY**  
Now heaven send thee good fortune!  

_Exit FENTON_

A kind heart he hath: a woman would run through  
fire and water for such a kind heart. But yet I  
would my master had Mistress Anne; or I would  
Master Slender had her; or, in sooth, I would Master  
Fenton had her; I will do what I can for them all  
three; for so I have promised, and I'll be as good  
as my word; but speciously for Master Fenton. Well,  
I must of another errand to Sir John Falstaff from  
my two mistresses: what a beast am I to slack it!  

_Exit_

### SCENE V. A room in the Garter Inn.

_Enter FALSTAFF and BARDOLPH_

**FALSTAFF**  
Bardolph, I say,--  

**BARDOLPH**  
Here, sir.  

**FALSTAFF**  
Go fetch me a quart of sack; put a toast in't.  

_Exit BARDOLPH_

Have I lived to be carried in a basket, like a  
barrow of butcher's offal, and to be thrown in the  
Thames? Well, if I be served such another trick,  
I'll have my brains ta'en out and buttered, and give  
them to a dog for a new-year's gift. The rogues  
slighted me into the river with as little remorse as  
they would have drowned a blind bitch's puppies,  
fifteen i' the litter: and you may know by my size  
that I have a kind of alacrity in sinking; if the  
bottom were as deep as hell, I should down. I had  
been drowned, but that the shore was shelvy and  
shallow,--a death that I abhor; for the water swells  
a man; and what a thing should I have been when I  
had been swelled! I should have been a mountain of mummy.  

_Re-enter BARDOLPH with sack_

**BARDOLPH**  
Here's Mistress Quickly, sir, to speak with you.  

**FALSTAFF**  
Let me pour in some sack to the Thames water; for my  
belly's as cold as if I had swallowed snowballs for  
pills to cool the reins. Call her in.  

**BARDOLPH**  
Come in, woman!  

_Enter MISTRESS QUICKLY_

**MISTRESS QUICKLY**  
By your leave; I cry you mercy: give your worship  
good morrow.  

**FALSTAFF**  
Take away these chalices. Go brew me a pottle of  
sack finely.  

**BARDOLPH**  
With eggs, sir?  

**FALSTAFF**  
Simple of itself; I'll no pullet-sperm in my brewage.  

_Exit BARDOLPH_

How now!  

**MISTRESS QUICKLY**  
Marry, sir, I come to your worship from Mistress Ford.  

**FALSTAFF**  
Mistress Ford! I have had ford enough; I was thrown  
into the ford; I have my belly full of ford.  

**MISTRESS QUICKLY**  
Alas the day! good heart, that was not her fault:  
she does so take on with her men; they mistook their erection.  

**FALSTAFF**  
So did I mine, to build upon a foolish woman's promise.  

**MISTRESS QUICKLY**  
Well, she laments, sir, for it, that it would yearn  
your heart to see it. Her husband goes this morning  
a-birding; she desires you once more to come to her  
between eight and nine: I must carry her word  
quickly: she'll make you amends, I warrant you.  

**FALSTAFF**  
Well, I will visit her: tell her so; and bid her  
think what a man is: let her consider his frailty,  
and then judge of my merit.  

**MISTRESS QUICKLY**  
I will tell her.  

**FALSTAFF**  
Do so. Between nine and ten, sayest thou?  

**MISTRESS QUICKLY**  
Eight and nine, sir.  

**FALSTAFF**  
Well, be gone: I will not miss her.  

**MISTRESS QUICKLY**  
Peace be with you, sir.  

_Exit_

**FALSTAFF**  
I marvel I hear not of Master Brook; he sent me word  
to stay within: I like his money well. O, here he comes.  

_Enter FORD_

**FORD**  
Bless you, sir!  

**FALSTAFF**  
Now, master Brook, you come to know what hath passed  
between me and Ford's wife?  

**FORD**  
That, indeed, Sir John, is my business.  

**FALSTAFF**  
Master Brook, I will not lie to you: I was at her  
house the hour she appointed me.  

**FORD**  
And sped you, sir?  

**FALSTAFF**  
Very ill-favoredly, Master Brook.  

**FORD**  
How so, sir? Did she change her determination?  

**FALSTAFF**  
No, Master Brook; but the peaking Cornuto her  
husband, Master Brook, dwelling in a continual  
'larum of jealousy, comes me in the instant of our  
encounter, after we had embraced, kissed, protested,  
and, as it were, spoke the prologue of our comedy;  
and at his heels a rabble of his companions, thither  
provoked and instigated by his distemper, and,  
forsooth, to search his house for his wife's love.  

**FORD**  
What, while you were there?  

**FALSTAFF**  
While I was there.  

**FORD**  
And did he search for you, and could not find you?  

**FALSTAFF**  
You shall hear. As good luck would have it, comes  
in one Mistress Page; gives intelligence of Ford's  
approach; and, in her invention and Ford's wife's  
distraction, they conveyed me into a buck-basket.  

**FORD**  
A buck-basket!  

**FALSTAFF**  
By the Lord, a buck-basket! rammed me in with foul  
shirts and smocks, socks, foul stockings, greasy  
napkins; that, Master Brook, there was the rankest  
compound of villanous smell that ever offended nostril.  

**FORD**  
And how long lay you there?  

**FALSTAFF**  
Nay, you shall hear, Master Brook, what I have  
suffered to bring this woman to evil for your good.  
Being thus crammed in the basket, a couple of Ford's  
knaves, his hinds, were called forth by their  
mistress to carry me in the name of foul clothes to  
Datchet-lane: they took me on their shoulders; met  
the jealous knave their master in the door, who  
asked them once or twice what they had in their  
basket: I quaked for fear, lest the lunatic knave  
would have searched it; but fate, ordaining he  
should be a cuckold, held his hand. Well: on went he  
for a search, and away went I for foul clothes. But  
mark the sequel, Master Brook: I suffered the pangs  
of three several deaths; first, an intolerable  
fright, to be detected with a jealous rotten  
bell-wether; next, to be compassed, like a good  
bilbo, in the circumference of a peck, hilt to  
point, heel to head; and then, to be stopped in,  
like a strong distillation, with stinking clothes  
that fretted in their own grease: think of that,--a  
man of my kidney,--think of that,--that am as subject  
to heat as butter; a man of continual dissolution  
and thaw: it was a miracle to scape suffocation.  
And in the height of this bath, when I was more than  
half stewed in grease, like a Dutch dish, to be  
thrown into the Thames, and cooled, glowing hot,  
in that surge, like a horse-shoe; think of  
that,--hissing hot,--think of that, Master Brook.  

**FORD**  
In good sadness, I am sorry that for my sake you  
have sufferd all this. My suit then is desperate;  
you'll undertake her no more?  

**FALSTAFF**  
Master Brook, I will be thrown into Etna, as I have  
been into Thames, ere I will leave her thus. Her  
husband is this morning gone a-birding: I have  
received from her another embassy of meeting; 'twixt  
eight and nine is the hour, Master Brook.  

**FORD**  
'Tis past eight already, sir.  

**FALSTAFF**  
Is it? I will then address me to my appointment.  
Come to me at your convenient leisure, and you shall  
know how I speed; and the conclusion shall be  
crowned with your enjoying her. Adieu. You shall  
have her, Master Brook; Master Brook, you shall  
cuckold Ford.  

_Exit_

**FORD**  
Hum! ha! is this a vision? is this a dream? do I  
sleep? Master Ford awake! awake, Master Ford!  
there's a hole made in your best coat, Master Ford.  
This 'tis to be married! this 'tis to have linen  
and buck-baskets! Well, I will proclaim myself  
what I am: I will now take the lecher; he is at my  
house; he cannot 'scape me; 'tis impossible he  
should; he cannot creep into a halfpenny purse,  
nor into a pepper-box: but, lest the devil that  
guides him should aid him, I will search  
impossible places. Though what I am I cannot avoid,  
yet to be what I would not shall not make me tame:  
if I have horns to make one mad, let the proverb go  
with me: I'll be horn-mad.  

_Exit_

# ACT IV

### SCENE I. A street.

_Enter MISTRESS PAGE, MISTRESS QUICKLY, and WILLIAM PAGE_

**MISTRESS PAGE**  
Is he at Master Ford's already, think'st thou?  

**MISTRESS QUICKLY**  
Sure he is by this, or will be presently: but,  
truly, he is very courageous mad about his throwing  
into the water. Mistress Ford desires you to come suddenly.  

**MISTRESS PAGE**  
I'll be with her by and by; I'll but bring my young  
man here to school. Look, where his master comes;  
'tis a playing-day, I see.  

_Enter SIR HUGH EVANS_

How now, Sir Hugh! no school to-day?  

**SIR HUGH EVANS**  
No; Master Slender is let the boys leave to play.  

**MISTRESS QUICKLY**  
Blessing of his heart!  

**MISTRESS PAGE**  
Sir Hugh, my husband says my son profits nothing in  
the world at his book. I pray you, ask him some  
questions in his accidence.  

**SIR HUGH EVANS**  
Come hither, William; hold up your head; come.  

**MISTRESS PAGE**  
Come on, sirrah; hold up your head; answer your  
master, be not afraid.  

**SIR HUGH EVANS**  
William, how many numbers is in nouns?  

**WILLIAM PAGE**  
Two.  

**MISTRESS QUICKLY**  
Truly, I thought there had been one number more,  
because they say, ''Od's nouns.'  

**SIR HUGH EVANS**  
Peace your tattlings! What is 'fair,' William?  

**WILLIAM PAGE**  
Pulcher.  

**MISTRESS QUICKLY**  
Polecats! there are fairer things than polecats, sure.  

**SIR HUGH EVANS**  
You are a very simplicity 'oman: I pray you peace.  
What is 'lapis,' William?  

**WILLIAM PAGE**  
A stone.  

**SIR HUGH EVANS**  
And what is 'a stone,' William?  

**WILLIAM PAGE**  
A pebble.  

**SIR HUGH EVANS**  
No, it is 'lapis:' I pray you, remember in your prain.  

**WILLIAM PAGE**  
Lapis.  

**SIR HUGH EVANS**  
That is a good William. What is he, William, that  
does lend articles?  

**WILLIAM PAGE**  
Articles are borrowed of the pronoun, and be thus  
declined, Singulariter, nominativo, hic, haec, hoc.  

**SIR HUGH EVANS**  
Nominativo, hig, hag, hog; pray you, mark:  
genitivo, hujus. Well, what is your accusative case?  

**WILLIAM PAGE**  
Accusativo, hinc.  

**SIR HUGH EVANS**  
I pray you, have your remembrance, child,  
accusative, hung, hang, hog.  

**MISTRESS QUICKLY**  
'Hang-hog' is Latin for bacon, I warrant you.  

**SIR HUGH EVANS**  
Leave your prabbles, 'oman. What is the focative  
case, William?  

**WILLIAM PAGE**  
O,--vocativo, O.  

**SIR HUGH EVANS**  
Remember, William; focative is caret.  

**MISTRESS QUICKLY**  
And that's a good root.  

**SIR HUGH EVANS**  
'Oman, forbear.  

**MISTRESS PAGE**  
Peace!  

**SIR HUGH EVANS**  
What is your genitive case plural, William?  

**WILLIAM PAGE**  
Genitive case!  

**SIR HUGH EVANS**  
Ay.  

**WILLIAM PAGE**  
Genitive,--horum, harum, horum.  

**MISTRESS QUICKLY**  
Vengeance of Jenny's case! fie on her! never name  
her, child, if she be a whore.  

**SIR HUGH EVANS**  
For shame, 'oman.  

**MISTRESS QUICKLY**  
You do ill to teach the child such words: he  
teaches him to hick and to hack, which they'll do  
fast enough of themselves, and to call 'horum:' fie upon you!  

**SIR HUGH EVANS**  
'Oman, art thou lunatics? hast thou no  
understandings for thy cases and the numbers of the  
genders? Thou art as foolish Christian creatures as  
I would desires.  

**MISTRESS PAGE**  
Prithee, hold thy peace.  

**SIR HUGH EVANS**  
Show me now, William, some declensions of your pronouns.  

**WILLIAM PAGE**  
Forsooth, I have forgot.  

**SIR HUGH EVANS**  
It is qui, quae, quod: if you forget your 'quies,'  
your 'quaes,' and your 'quods,' you must be  
preeches. Go your ways, and play; go.  

**MISTRESS PAGE**  
He is a better scholar than I thought he was.  

**SIR HUGH EVANS**  
He is a good sprag memory. Farewell, Mistress Page.  

**MISTRESS PAGE**  
Adieu, good Sir Hugh.  

_Exit SIR HUGH EVANS_

Get you home, boy. Come, we stay too long.  

_Exeunt_

### SCENE II. A room in FORD'S house.

_Enter FALSTAFF and MISTRESS FORD_

**FALSTAFF**  
Mistress Ford, your sorrow hath eaten up my  
sufferance. I see you are obsequious in your love,  
and I profess requital to a hair's breadth; not  
only, Mistress Ford, in the simple  
office of love, but in all the accoutrement,  
complement and ceremony of it. But are you  
sure of your husband now?  

**MISTRESS FORD**  
He's a-birding, sweet Sir John.  

**MISTRESS PAGE**  
[Within]_  
What, ho, gossip Ford! what, ho!  

**MISTRESS FORD**  
Step into the chamber, Sir John.  

_Exit FALSTAFF_

_Enter MISTRESS PAGE_

**MISTRESS PAGE**  
How now, sweetheart! who's at home besides yourself?  

**MISTRESS FORD**  
Why, none but mine own people.  

**MISTRESS PAGE**  
Indeed!  

**MISTRESS FORD**  
No, certainly.  

_Aside to her_

Speak louder.  

**MISTRESS PAGE**  
Truly, I am so glad you have nobody here.  

**MISTRESS FORD**  
Why?  

**MISTRESS PAGE**  
Why, woman, your husband is in his old lunes again:  
he so takes on yonder with my husband; so rails  
against all married mankind; so curses all Eve's  
daughters, of what complexion soever; and so buffets  
himself on the forehead, crying, 'Peer out, peer  
out!' that any madness I ever yet beheld seemed but  
tameness, civility and patience, to this his  
distemper he is in now: I am glad the fat knight is not here.  

**MISTRESS FORD**  
Why, does he talk of him?  

**MISTRESS PAGE**  
Of none but him; and swears he was carried out, the  
last time he searched for him, in a basket; protests  
to my husband he is now here, and hath drawn him and  
the rest of their company from their sport, to make  
another experiment of his suspicion: but I am glad  
the knight is not here; now he shall see his own foolery.  

**MISTRESS FORD**  
How near is he, Mistress Page?  

**MISTRESS PAGE**  
Hard by; at street end; he will be here anon.  

**MISTRESS FORD**  
I am undone! The knight is here.  

**MISTRESS PAGE**  
Why then you are utterly shamed, and he's but a dead  
man. What a woman are you!--Away with him, away  
with him! better shame than murder.  

**FORD**  
Which way should be go? how should I bestow him?  
Shall I put him into the basket again?  

_Re-enter FALSTAFF_

**FALSTAFF**  
No, I'll come no more i' the basket. May I not go  
out ere he come?  

**MISTRESS PAGE**  
Alas, three of Master Ford's brothers watch the door  
with pistols, that none shall issue out; otherwise  
you might slip away ere he came. But what make you here?  

**FALSTAFF**  
What shall I do? I'll creep up into the chimney.  

**MISTRESS FORD**  
There they always use to discharge their  
birding-pieces. Creep into the kiln-hole.  

**FALSTAFF**  
Where is it?  

**MISTRESS FORD**  
He will seek there, on my word. Neither press,  
coffer, chest, trunk, well, vault, but he hath an  
abstract for the remembrance of such places, and  
goes to them by his note: there is no hiding you in the house.  

**FALSTAFF**  
I'll go out then.  

**MISTRESS PAGE**  
If you go out in your own semblance, you die, Sir  
John. Unless you go out disguised--  

**MISTRESS FORD**  
How might we disguise him?  

**MISTRESS PAGE**  
Alas the day, I know not! There is no woman's gown  
big enough for him otherwise he might put on a hat,  
a muffler and a kerchief, and so escape.  

**FALSTAFF**  
Good hearts, devise something: any extremity rather  
than a mischief.  

**MISTRESS FORD**  
My maid's aunt, the fat woman of Brentford, has a  
gown above.  

**MISTRESS PAGE**  
On my word, it will serve him; she's as big as he  
is: and there's her thrummed hat and her muffler  
too. Run up, Sir John.  

**MISTRESS FORD**  
Go, go, sweet Sir John: Mistress Page and I will  
look some linen for your head.  

**MISTRESS PAGE**  
Quick, quick! we'll come dress you straight: put  
on the gown the while.  

_Exit FALSTAFF_

**MISTRESS FORD**  
I would my husband would meet him in this shape: he  
cannot abide the old woman of Brentford; he swears  
she's a witch; forbade her my house and hath  
threatened to beat her.  

**MISTRESS PAGE**  
Heaven guide him to thy husband's cudgel, and the  
devil guide his cudgel afterwards!  

**MISTRESS FORD**  
But is my husband coming?  

**MISTRESS PAGE**  
Ah, in good sadness, is he; and talks of the basket  
too, howsoever he hath had intelligence.  

**MISTRESS FORD**  
We'll try that; for I'll appoint my men to carry the  
basket again, to meet him at the door with it, as  
they did last time.  

**MISTRESS PAGE**  
Nay, but he'll be here presently: let's go dress him  
like the witch of Brentford.  

**MISTRESS FORD**  
I'll first direct my men what they shall do with the  
basket. Go up; I'll bring linen for him straight.  

_Exit_

**MISTRESS PAGE**  
Hang him, dishonest varlet! we cannot misuse him enough.  
We'll leave a proof, by that which we will do,  
Wives may be merry, and yet honest too:  
We do not act that often jest and laugh;  
'Tis old, but true, Still swine eat all the draff.  

_Exit_

_Re-enter MISTRESS FORD with two Servants_

**MISTRESS FORD**  
Go, sirs, take the basket again on your shoulders:  
your master is hard at door; if he bid you set it  
down, obey him: quickly, dispatch.  

_Exit_

**First Servant**  
Come, come, take it up.  

**Second Servant**  
Pray heaven it be not full of knight again.  

**First Servant**  
I hope not; I had as lief bear so much lead.  

_Enter FORD, PAGE, SHALLOW, DOCTOR CAIUS, and SIR HUGH EVANS_

**FORD**  
Ay, but if it prove true, Master Page, have you any  
way then to unfool me again? Set down the basket,  
villain! Somebody call my wife. Youth in a basket!  
O you panderly rascals! there's a knot, a ging, a  
pack, a conspiracy against me: now shall the devil  
be shamed. What, wife, I say! Come, come forth!  
Behold what honest clothes you send forth to bleaching!  

**PAGE**  
Why, this passes, Master Ford; you are not to go  
loose any longer; you must be pinioned.  

**SIR HUGH EVANS**  
Why, this is lunatics! this is mad as a mad dog!  

**SHALLOW**  
Indeed, Master Ford, this is not well, indeed.  

**FORD**  
So say I too, sir.  

_Re-enter MISTRESS FORD_

Come hither, Mistress Ford; Mistress Ford the honest  
woman, the modest wife, the virtuous creature, that  
hath the jealous fool to her husband! I suspect  
without cause, mistress, do I?  

**MISTRESS FORD**  
Heaven be my witness you do, if you suspect me in  
any dishonesty.  

**FORD**  
Well said, brazen-face! hold it out. Come forth, sirrah!  

_Pulling clothes out of the basket_

**PAGE**  
This passes!  

**MISTRESS FORD**  
Are you not ashamed? let the clothes alone.  

**FORD**  
I shall find you anon.  

**SIR HUGH EVANS**  
'Tis unreasonable! Will you take up your wife's  
clothes? Come away.  

**FORD**  
Empty the basket, I say!  

**MISTRESS FORD**  
Why, man, why?  

**FORD**  
Master Page, as I am a man, there was one conveyed  
out of my house yesterday in this basket: why may  
not he be there again? In my house I am sure he is:  
my intelligence is true; my jealousy is reasonable.  
Pluck me out all the linen.  

**MISTRESS FORD**  
If you find a man there, he shall die a flea's death.  

**PAGE**  
Here's no man.  

**SHALLOW**  
By my fidelity, this is not well, Master Ford; this  
wrongs you.  

**SIR HUGH EVANS**  
Master Ford, you must pray, and not follow the  
imaginations of your own heart: this is jealousies.  

**FORD**  
Well, he's not here I seek for.  

**PAGE**  
No, nor nowhere else but in your brain.  

**FORD**  
Help to search my house this one time. If I find  
not what I seek, show no colour for my extremity; let  
me for ever be your table-sport; let them say of  
me, 'As jealous as Ford, Chat searched a hollow  
walnut for his wife's leman.' Satisfy me once more;  
once more search with me.  

**MISTRESS FORD**  
What, ho, Mistress Page! come you and the old woman  
down; my husband will come into the chamber.  

**FORD**  
Old woman! what old woman's that?  

**MISTRESS FORD**  
Nay, it is my maid's aunt of Brentford.  

**FORD**  
A witch, a quean, an old cozening quean! Have I not  
forbid her my house? She comes of errands, does  
she? We are simple men; we do not know what's  
brought to pass under the profession of  
fortune-telling. She works by charms, by spells,  
by the figure, and such daubery as this is, beyond  
our element we know nothing. Come down, you witch,  
you hag, you; come down, I say!  

**MISTRESS FORD**  
Nay, good, sweet husband! Good gentlemen, let him  
not strike the old woman.  

_Re-enter FALSTAFF in woman 's clothes, and MISTRESS PAGE_

**MISTRESS PAGE**  
Come, Mother Prat; come, give me your hand.  

**FORD**  
I'll prat her.  

_Beating him_

Out of my door, you witch, you hag, you baggage, you  
polecat, you runyon! out, out! I'll conjure you,  
I'll fortune-tell you.  

_Exit FALSTAFF_

**MISTRESS PAGE**  
Are you not ashamed? I think you have killed the  
poor woman.  

**MISTRESS FORD**  
Nay, he will do it. 'Tis a goodly credit for you.  

**FORD**  
Hang her, witch!  

**SIR HUGH EVANS**  
By the yea and no, I think the 'oman is a witch  
indeed: I like not when a 'oman has a great peard;  
I spy a great peard under his muffler.  

**FORD**  
Will you follow, gentlemen? I beseech you, follow;  
see but the issue of my jealousy: if I cry out thus  
upon no trail, never trust me when I open again.  

**PAGE**  
Let's obey his humour a little further: come,  
gentlemen.  

_Exeunt FORD, PAGE, SHALLOW, DOCTOR CAIUS, and SIR HUGH EVANS_

**MISTRESS PAGE**  
Trust me, he beat him most pitifully.  

**MISTRESS FORD**  
Nay, by the mass, that he did not; he beat him most  
unpitifully, methought.  

**MISTRESS PAGE**  
I'll have the cudgel hallowed and hung o'er the  
altar; it hath done meritorious service.  

**MISTRESS FORD**  
What think you? may we, with the warrant of  
womanhood and the witness of a good conscience,  
pursue him with any further revenge?  

**MISTRESS PAGE**  
The spirit of wantonness is, sure, scared out of  
him: if the devil have him not in fee-simple, with  
fine and recovery, he will never, I think, in the  
way of waste, attempt us again.  

**MISTRESS FORD**  
Shall we tell our husbands how we have served him?  

**MISTRESS PAGE**  
Yes, by all means; if it be but to scrape the  
figures out of your husband's brains. If they can  
find in their hearts the poor unvirtuous fat knight  
shall be any further afflicted, we two will still be  
the ministers.  

**MISTRESS FORD**  
I'll warrant they'll have him publicly shamed: and  
methinks there would be no period to the jest,  
should he not be publicly shamed.  

**MISTRESS PAGE**  
Come, to the forge with it then; shape it: I would  
not have things cool.  

_Exeunt_

### SCENE III. A room in the Garter Inn.

_Enter Host and BARDOLPH_

**BARDOLPH**  
Sir, the Germans desire to have three of your  
horses: the duke himself will be to-morrow at  
court, and they are going to meet him.  

**Host**  
What duke should that be comes so secretly? I hear  
not of him in the court. Let me speak with the  
gentlemen: they speak English?  

**BARDOLPH**  
Ay, sir; I'll call them to you.  

**Host**  
They shall have my horses; but I'll make them pay;  
I'll sauce them: they have had my house a week at  
command; I have turned away my other guests: they  
must come off; I'll sauce them. Come.  

_Exeunt_

### SCENE IV. A room in FORD'S house.

_Enter PAGE, FORD, MISTRESS PAGE, MISTRESS FORD, and SIR HUGH EVANS_

**SIR HUGH EVANS**  
'Tis one of the best discretions of a 'oman as ever  
I did look upon.  

**PAGE**  
And did he send you both these letters at an instant?  

**MISTRESS PAGE**  
Within a quarter of an hour.  

**FORD**  
Pardon me, wife. Henceforth do what thou wilt;  
I rather will suspect the sun with cold  
Than thee with wantonness: now doth thy honour stand  
In him that was of late an heretic,  
As firm as faith.  

**PAGE**  
'Tis well, 'tis well; no more:  
Be not as extreme in submission  
As in offence.  
But let our plot go forward: let our wives  
Yet once again, to make us public sport,  
Appoint a meeting with this old fat fellow,  
Where we may take him and disgrace him for it.  

**FORD**  
There is no better way than that they spoke of.  

**PAGE**  
How? to send him word they'll meet him in the park  
at midnight? Fie, fie! he'll never come.  

**SIR HUGH EVANS**  
You say he has been thrown in the rivers and has  
been grievously peaten as an old 'oman: methinks  
there should be terrors in him that he should not  
come; methinks his flesh is punished, he shall have  
no desires.  

**PAGE**  
So think I too.  

**MISTRESS FORD**  
Devise but how you'll use him when he comes,  
And let us two devise to bring him thither.  

**MISTRESS PAGE**  
There is an old tale goes that Herne the hunter,  
Sometime a keeper here in Windsor forest,  
Doth all the winter-time, at still midnight,  
Walk round about an oak, with great ragg'd horns;  
And there he blasts the tree and takes the cattle  
And makes milch-kine yield blood and shakes a chain  
In a most hideous and dreadful manner:  
You have heard of such a spirit, and well you know  
The superstitious idle-headed eld  
Received and did deliver to our age  
This tale of Herne the hunter for a truth.  

**PAGE**  
Why, yet there want not many that do fear  
In deep of night to walk by this Herne's oak:  
But what of this?  

**MISTRESS FORD**  
Marry, this is our device;  
That Falstaff at that oak shall meet with us.  

**PAGE**  
Well, let it not be doubted but he'll come:  
And in this shape when you have brought him thither,  
What shall be done with him? what is your plot?  

**MISTRESS PAGE**  
That likewise have we thought upon, and thus:  
Nan Page my daughter and my little son  
And three or four more of their growth we'll dress  
Like urchins, ouphes and fairies, green and white,  
With rounds of waxen tapers on their heads,  
And rattles in their hands: upon a sudden,  
As Falstaff, she and I, are newly met,  
Let them from forth a sawpit rush at once  
With some diffused song: upon their sight,  
We two in great amazedness will fly:  
Then let them all encircle him about  
And, fairy-like, to-pinch the unclean knight,  
And ask him why, that hour of fairy revel,  
In their so sacred paths he dares to tread  
In shape profane.  

**MISTRESS FORD**  
And till he tell the truth,  
Let the supposed fairies pinch him sound  
And burn him with their tapers.  

**MISTRESS PAGE**  
The truth being known,  
We'll all present ourselves, dis-horn the spirit,  
And mock him home to Windsor.  

**FORD**  
The children must  
Be practised well to this, or they'll ne'er do't.  

**SIR HUGH EVANS**  
I will teach the children their behaviors; and I  
will be like a jack-an-apes also, to burn the  
knight with my taber.  

**FORD**  
That will be excellent. I'll go and buy them vizards.  

**MISTRESS PAGE**  
My Nan shall be the queen of all the fairies,  
Finely attired in a robe of white.  

**PAGE**  
That silk will I go buy.  

_[Aside]_  
And in that time  
Shall Master Slender steal my Nan away  
And marry her at Eton. Go send to Falstaff straight.  

**FORD**  
Nay I'll to him again in name of Brook  
He'll tell me all his purpose: sure, he'll come.  

**MISTRESS PAGE**  
Fear not you that. Go get us properties  
And tricking for our fairies.  

**SIR HUGH EVANS**  
Let us about it: it is admirable pleasures and fery  
honest knaveries.  

_Exeunt PAGE, FORD, and SIR HUGH EVANS_

**MISTRESS PAGE**  
Go, Mistress Ford,  
Send quickly to Sir John, to know his mind.  

_Exit MISTRESS FORD_

I'll to the doctor: he hath my good will,  
And none but he, to marry with Nan Page.  
That Slender, though well landed, is an idiot;  
And he my husband best of all affects.  
The doctor is well money'd, and his friends  
Potent at court: he, none but he, shall have her,  
Though twenty thousand worthier come to crave her.  

_Exit_

### SCENE V. A room in the Garter Inn.

_Enter Host and SIMPLE_

**Host**  
What wouldst thou have, boor? what: thick-skin?  
speak, breathe, discuss; brief, short, quick, snap.  

**SIMPLE**  
Marry, sir, I come to speak with Sir John Falstaff  
from Master Slender.  

**Host**  
There's his chamber, his house, his castle, his  
standing-bed and truckle-bed; 'tis painted about  
with the story of the Prodigal, fresh and new. Go  
knock and call; hell speak like an Anthropophaginian  
unto thee: knock, I say.  

**SIMPLE**  
There's an old woman, a fat woman, gone up into his  
chamber: I'll be so bold as stay, sir, till she come  
down; I come to speak with her, indeed.  

**Host**  
Ha! a fat woman! the knight may be robbed: I'll  
call. Bully knight! bully Sir John! speak from  
thy lungs military: art thou there? it is thine  
host, thine Ephesian, calls.  

**FALSTAFF**  
[Above]_  
How now, mine host!  

**Host**  
Here's a Bohemian-Tartar tarries the coming down of  
thy fat woman. Let her descend, bully, let her  
descend; my chambers are honourable: fie! privacy?  
fie!  

_Enter FALSTAFF_

**FALSTAFF**  
There was, mine host, an old fat woman even now with  
me; but she's gone.  

**SIMPLE**  
Pray you, sir, was't not the wise woman of  
Brentford?  

**FALSTAFF**  
Ay, marry, was it, mussel-shell: what would you with her?  

**SIMPLE**  
My master, sir, Master Slender, sent to her, seeing  
her go through the streets, to know, sir, whether  
one Nym, sir, that beguiled him of a chain, had the  
chain or no.  

**FALSTAFF**  
I spake with the old woman about it.  

**SIMPLE**  
And what says she, I pray, sir?  

**FALSTAFF**  
Marry, she says that the very same man that  
beguiled Master Slender of his chain cozened him of  
it.  

**SIMPLE**  
I would I could have spoken with the woman herself;  
I had other things to have spoken with her too from  
him.  

**FALSTAFF**  
What are they? let us know.  

**Host**  
Ay, come; quick.  

**SIMPLE**  
I may not conceal them, sir.  

**Host**  
Conceal them, or thou diest.  

**SIMPLE**  
Why, sir, they were nothing but about Mistress Anne  
Page; to know if it were my master's fortune to  
have her or no.  

**FALSTAFF**  
'Tis, 'tis his fortune.  

**SIMPLE**  
What, sir?  

**FALSTAFF**  
To have her, or no. Go; say the woman told me so.  

**SIMPLE**  
May I be bold to say so, sir?  

**FALSTAFF**  
Ay, sir; like who more bold.  

**SIMPLE**  
I thank your worship: I shall make my master glad  
with these tidings.  

_Exit_

**Host**  
Thou art clerkly, thou art clerkly, Sir John. Was  
there a wise woman with thee?  

**FALSTAFF**  
Ay, that there was, mine host; one that hath taught  
me more wit than ever I learned before in my life;  
and I paid nothing for it neither, but was paid for  
my learning.  

_Enter BARDOLPH_

**BARDOLPH**  
Out, alas, sir! cozenage, mere cozenage!  

**Host**  
Where be my horses? speak well of them, varletto.  

**BARDOLPH**  
Run away with the cozeners; for so soon as I came  
beyond Eton, they threw me off from behind one of  
them, in a slough of mire; and set spurs and away,  
like three German devils, three Doctor Faustuses.  

**Host**  
They are gone but to meet the duke, villain: do not  
say they be fled; Germans are honest men.  

_Enter SIR HUGH EVANS_

**SIR HUGH EVANS**  
Where is mine host?  

**Host**  
What is the matter, sir?  

**SIR HUGH EVANS**  
Have a care of your entertainments: there is a  
friend of mine come to town tells me there is three  
cozen-germans that has cozened all the hosts of  
Readins, of Maidenhead, of Colebrook, of horses and  
money. I tell you for good will, look you: you  
are wise and full of gibes and vlouting-stocks, and  
'tis not convenient you should be cozened. Fare you well.  

_Exit_

_Enter DOCTOR CAIUS_

**DOCTOR CAIUS**  
Vere is mine host de Jarteer?  

**Host**  
Here, master doctor, in perplexity and doubtful dilemma.  

**DOCTOR CAIUS**  
I cannot tell vat is dat: but it is tell-a me dat  
you make grand preparation for a duke de Jamany: by  
my trot, dere is no duke dat the court is know to  
come. I tell you for good vill: adieu.  

_Exit_

**Host**  
Hue and cry, villain, go! Assist me, knight. I am  
undone! Fly, run, hue and cry, villain! I am undone!  

_Exeunt Host and BARDOLPH_

**FALSTAFF**  
I would all the world might be cozened; for I have  
been cozened and beaten too. If it should come to  
the ear of the court, how I have been transformed  
and how my transformation hath been washed and  
cudgelled, they would melt me out of my fat drop by  
drop and liquor fishermen's boots with me; I warrant  
they would whip me with their fine wits till I were  
as crest-fallen as a dried pear. I never prospered  
since I forswore myself at primero. Well, if my  
wind were but long enough to say my prayers, I would repent.  

_Enter MISTRESS QUICKLY_

Now, whence come you?  

**MISTRESS QUICKLY**  
From the two parties, forsooth.  

**FALSTAFF**  
The devil take one party and his dam the other! and  
so they shall be both bestowed. I have suffered more  
for their sakes, more than the villanous inconstancy  
of man's disposition is able to bear.  

**MISTRESS QUICKLY**  
And have not they suffered? Yes, I warrant;  
speciously one of them; Mistress Ford, good heart,  
is beaten black and blue, that you cannot see a  
white spot about her.  

**FALSTAFF**  
What tellest thou me of black and blue? I was  
beaten myself into all the colours of the rainbow;  
and I was like to be apprehended for the witch of  
Brentford: but that my admirable dexterity of wit,  
my counterfeiting the action of an old woman,  
delivered me, the knave constable had set me i' the  
stocks, i' the common stocks, for a witch.  

**MISTRESS QUICKLY**  
Sir, let me speak with you in your chamber: you  
shall hear how things go; and, I warrant, to your  
content. Here is a letter will say somewhat. Good  
hearts, what ado here is to bring you together!  
Sure, one of you does not serve heaven well, that  
you are so crossed.  

**FALSTAFF**  
Come up into my chamber.  

_Exeunt_

### SCENE VI. Another room in the Garter Inn.

_Enter FENTON and Host_

**Host**  
Master Fenton, talk not to me; my mind is heavy: I  
will give over all.  

**FENTON**  
Yet hear me speak. Assist me in my purpose,  
And, as I am a gentleman, I'll give thee  
A hundred pound in gold more than your loss.  

**Host**  
I will hear you, Master Fenton; and I will at the  
least keep your counsel.  

**FENTON**  
From time to time I have acquainted you  
With the dear love I bear to fair Anne Page;  
Who mutually hath answer'd my affection,  
So far forth as herself might be her chooser,  
Even to my wish: I have a letter from her  
Of such contents as you will wonder at;  
The mirth whereof so larded with my matter,  
That neither singly can be manifested,  
Without the show of both; fat Falstaff  
Hath a great scene: the image of the jest  
I'll show you here at large. Hark, good mine host.  
To-night at Herne's oak, just 'twixt twelve and one,  
Must my sweet Nan present the Fairy Queen;  
The purpose why, is here: in which disguise,  
While other jests are something rank on foot,  
Her father hath commanded her to slip  
Away with Slender and with him at Eton  
Immediately to marry: she hath consented: Now, sir,  
Her mother, ever strong against that match  
And firm for Doctor Caius, hath appointed  
That he shall likewise shuffle her away,  
While other sports are tasking of their minds,  
And at the deanery, where a priest attends,  
Straight marry her: to this her mother's plot  
She seemingly obedient likewise hath  
Made promise to the doctor. Now, thus it rests:  
Her father means she shall be all in white,  
And in that habit, when Slender sees his time  
To take her by the hand and bid her go,  
She shall go with him: her mother hath intended,  
The better to denote her to the doctor,  
For they must all be mask'd and vizarded,  
That quaint in green she shall be loose enrobed,  
With ribands pendent, flaring 'bout her head;  
And when the doctor spies his vantage ripe,  
To pinch her by the hand, and, on that token,  
The maid hath given consent to go with him.  

**Host**  
Which means she to deceive, father or mother?  

**FENTON**  
Both, my good host, to go along with me:  
And here it rests, that you'll procure the vicar  
To stay for me at church 'twixt twelve and one,  
And, in the lawful name of marrying,  
To give our hearts united ceremony.  

**Host**  
Well, husband your device; I'll to the vicar:  
Bring you the maid, you shall not lack a priest.  

**FENTON**  
So shall I evermore be bound to thee;  
Besides, I'll make a present recompense.  

_Exeunt_

# ACT V

### SCENE I. A room in the Garter Inn.

_Enter FALSTAFF and MISTRESS QUICKLY_

**FALSTAFF**  
Prithee, no more prattling; go. I'll hold. This is  
the third time; I hope good luck lies in odd  
numbers. Away I go. They say there is divinity in  
odd numbers, either in nativity, chance, or death. Away!  

**MISTRESS QUICKLY**  
I'll provide you a chain; and I'll do what I can to  
get you a pair of horns.  

**FALSTAFF**  
Away, I say; time wears: hold up your head, and mince.  

_Exit MISTRESS QUICKLY_

_Enter FORD_

How now, Master Brook! Master Brook, the matter  
will be known to-night, or never. Be you in the  
Park about midnight, at Herne's oak, and you shall  
see wonders.  

**FORD**  
Went you not to her yesterday, sir, as you told me  
you had appointed?  

**FALSTAFF**  
I went to her, Master Brook, as you see, like a poor  
old man: but I came from her, Master Brook, like a  
poor old woman. That same knave Ford, her husband,  
hath the finest mad devil of jealousy in him,  
Master Brook, that ever governed frenzy. I will tell  
you: he beat me grievously, in the shape of a  
woman; for in the shape of man, Master Brook, I fear  
not Goliath with a weaver's beam; because I know  
also life is a shuttle. I am in haste; go along  
with me: I'll tell you all, Master Brook. Since I  
plucked geese, played truant and whipped top, I knew  
not what 'twas to be beaten till lately. Follow  
me: I'll tell you strange things of this knave  
Ford, on whom to-night I will be revenged, and I  
will deliver his wife into your hand. Follow.  
Strange things in hand, Master Brook! Follow.  

_Exeunt_

### SCENE II. Windsor Park.

_Enter PAGE, SHALLOW, and SLENDER_

**PAGE**  
Come, come; we'll couch i' the castle-ditch till we  
see the light of our fairies. Remember, son Slender,  
my daughter.  

**SLENDER**  
Ay, forsooth; I have spoke with her and we have a  
nay-word how to know one another: I come to her in  
white, and cry 'mum;' she cries 'budget;' and by  
that we know one another.  

**SHALLOW**  
That's good too: but what needs either your 'mum'  
or her 'budget?' the white will decipher her well  
enough. It hath struck ten o'clock.  

**PAGE**  
The night is dark; light and spirits will become it  
well. Heaven prosper our sport! No man means evil  
but the devil, and we shall know him by his horns.  
Let's away; follow me.  

_Exeunt_

### SCENE III. A street leading to the Park.

_Enter MISTRESS PAGE, MISTRESS FORD, and DOCTOR CAIUS_

**MISTRESS PAGE**  
Master doctor, my daughter is in green: when you  
see your time, take her by the band, away with her  
to the deanery, and dispatch it quickly. Go before  
into the Park: we two must go together.  

**DOCTOR CAIUS**  
I know vat I have to do. Adieu.  

**MISTRESS PAGE**  
Fare you well, sir.  

_Exit DOCTOR CAIUS_

My husband will not rejoice so much at the abuse of  
Falstaff as he will chafe at the doctor's marrying  
my daughter: but 'tis no matter; better a little  
chiding than a great deal of heart-break.  

**MISTRESS FORD**  
Where is Nan now and her troop of fairies, and the  
Welsh devil Hugh?  

**MISTRESS PAGE**  
They are all couched in a pit hard by Herne's oak,  
with obscured lights; which, at the very instant of  
Falstaff's and our meeting, they will at once  
display to the night.  

**MISTRESS FORD**  
That cannot choose but amaze him.  

**MISTRESS PAGE**  
If he be not amazed, he will be mocked; if he be  
amazed, he will every way be mocked.  

**MISTRESS FORD**  
We'll betray him finely.  

**MISTRESS PAGE**  
Against such lewdsters and their lechery  
Those that betray them do no treachery.  

**MISTRESS FORD**  
The hour draws on. To the oak, to the oak!  

_Exeunt_

### SCENE IV. Windsor Park.

_Enter SIR HUGH EVANS, disguised, with others as Fairies_

**SIR HUGH EVANS**  
Trib, trib, fairies; come; and remember your parts:  
be pold, I pray you; follow me into the pit; and  
when I give the watch-'ords, do as I pid you:  
come, come; trib, trib.  

_Exeunt_

### SCENE V. Another part of the Park.

_Enter FALSTAFF disguised as Herne_

**FALSTAFF**  
The Windsor bell hath struck twelve; the minute  
draws on. Now, the hot-blooded gods assist me!  
Remember, Jove, thou wast a bull for thy Europa; love  
set on thy horns. O powerful love! that, in some  
respects, makes a beast a man, in some other, a man  
a beast. You were also, Jupiter, a swan for the love  
of Leda. O omnipotent Love! how near the god drew  
to the complexion of a goose! A fault done first in  
the form of a beast. O Jove, a beastly fault! And  
then another fault in the semblance of a fowl; think  
on 't, Jove; a foul fault! When gods have hot  
backs, what shall poor men do? For me, I am here a  
Windsor stag; and the fattest, I think, i' the  
forest. Send me a cool rut-time, Jove, or who can  
blame me to piss my tallow? Who comes here? my  
doe?  

_Enter MISTRESS FORD and MISTRESS PAGE_

**MISTRESS FORD**  
Sir John! art thou there, my deer? my male deer?  

**FALSTAFF**  
My doe with the black scut! Let the sky rain  
potatoes; let it thunder to the tune of Green  
Sleeves, hail kissing-comfits and snow eringoes; let  
there come a tempest of provocation, I will shelter me here.  

**MISTRESS FORD**  
Mistress Page is come with me, sweetheart.  

**FALSTAFF**  
Divide me like a bribe buck, each a haunch: I will  
keep my sides to myself, my shoulders for the fellow  
of this walk, and my horns I bequeath your husbands.  
Am I a woodman, ha? Speak I like Herne the hunter?  
Why, now is Cupid a child of conscience; he makes  
restitution. As I am a true spirit, welcome!  

_Noise within_

**MISTRESS PAGE**  
Alas, what noise?  

**MISTRESS FORD**  
Heaven forgive our sins  

**FALSTAFF**  
What should this be?  

**MISTRESS FORD** **MISTRESS PAGE**  
Away, away!  

_They run off_

**FALSTAFF**  
I think the devil will not have me damned, lest the  
oil that's in me should set hell on fire; he would  
never else cross me thus.  

_Enter SIR HUGH EVANS, disguised as before; PISTOL, as Hobgoblin; MISTRESS
QUICKLY, ANNE PAGE, and others, as Fairies, with tapers_

**MISTRESS QUICKLY**  
Fairies, black, grey, green, and white,  
You moonshine revellers and shades of night,  
You orphan heirs of fixed destiny,  
Attend your office and your quality.  
Crier Hobgoblin, make the fairy oyes.  

**PISTOL**  
Elves, list your names; silence, you airy toys.  
Cricket, to Windsor chimneys shalt thou leap:  
Where fires thou find'st unraked and hearths unswept,  
There pinch the maids as blue as bilberry:  
Our radiant queen hates sluts and sluttery.  

**FALSTAFF**  
They are fairies; he that speaks to them shall die:  
I'll wink and couch: no man their works must eye.  

_Lies down upon his face_

**SIR HUGH EVANS**  
Where's Bede? Go you, and where you find a maid  
That, ere she sleep, has thrice her prayers said,  
Raise up the organs of her fantasy;  
Sleep she as sound as careless infancy:  
But those as sleep and think not on their sins,  
Pinch them, arms, legs, backs, shoulders, sides and shins.  

**MISTRESS QUICKLY**  
About, about;  
Search Windsor Castle, elves, within and out:  
Strew good luck, ouphes, on every sacred room:  
That it may stand till the perpetual doom,  
In state as wholesome as in state 'tis fit,  
Worthy the owner, and the owner it.  
The several chairs of order look you scour  
With juice of balm and every precious flower:  
Each fair instalment, coat, and several crest,  
With loyal blazon, evermore be blest!  
And nightly, meadow-fairies, look you sing,  
Like to the Garter's compass, in a ring:  
The expressure that it bears, green let it be,  
More fertile-fresh than all the field to see;  
And 'Honi soit qui mal y pense' write  
In emerald tufts, flowers purple, blue and white;  
Let sapphire, pearl and rich embroidery,  
Buckled below fair knighthood's bending knee:  
Fairies use flowers for their charactery.  
Away; disperse: but till 'tis one o'clock,  
Our dance of custom round about the oak  
Of Herne the hunter, let us not forget.  

**SIR HUGH EVANS**  
Pray you, lock hand in hand; yourselves in order set  
And twenty glow-worms shall our lanterns be,  
To guide our measure round about the tree.  
But, stay; I smell a man of middle-earth.  

**FALSTAFF**  
Heavens defend me from that Welsh fairy, lest he  
transform me to a piece of cheese!  

**PISTOL**  
Vile worm, thou wast o'erlook'd even in thy birth.  

**MISTRESS QUICKLY**  
With trial-fire touch me his finger-end:  
If he be chaste, the flame will back descend  
And turn him to no pain; but if he start,  
It is the flesh of a corrupted heart.  

**PISTOL**  
A trial, come.  

**SIR HUGH EVANS**  
Come, will this wood take fire?  

_They burn him with their tapers_

**FALSTAFF**  
Oh, Oh, Oh!  

**MISTRESS QUICKLY**  
Corrupt, corrupt, and tainted in desire!  
About him, fairies; sing a scornful rhyme;  
And, as you trip, still pinch him to your time.  
SONG.  
Fie on sinful fantasy!  
Fie on lust and luxury!  
Lust is but a bloody fire,  
Kindled with unchaste desire,  
Fed in heart, whose flames aspire  
As thoughts do blow them, higher and higher.  
Pinch him, fairies, mutually;  
Pinch him for his villany;  
Pinch him, and burn him, and turn him about,  
Till candles and starlight and moonshine be out.  

_During this song they pinch FALSTAFF. DOCTOR CAIUS comes one way, and
steals away a boy in green; SLENDER another way, and takes off a boy in white;
and FENTON comes and steals away ANN PAGE. A noise of hunting is heard within.
All the Fairies run away. FALSTAFF pulls off his buck 's head, and rises_

_Enter PAGE, FORD, MISTRESS PAGE, and MISTRESS FORD_

**PAGE**  
Nay, do not fly; I think we have watch'd you now  
Will none but Herne the hunter serve your turn?  

**MISTRESS PAGE**  
I pray you, come, hold up the jest no higher  
Now, good Sir John, how like you Windsor wives?  
See you these, husband? do not these fair yokes  
Become the forest better than the town?  

**FORD**  
Now, sir, who's a cuckold now? Master Brook,  
Falstaff's a knave, a cuckoldly knave; here are his  
horns, Master Brook: and, Master Brook, he hath  
enjoyed nothing of Ford's but his buck-basket, his  
cudgel, and twenty pounds of money, which must be  
paid to Master Brook; his horses are arrested for  
it, Master Brook.  

**MISTRESS FORD**  
Sir John, we have had ill luck; we could never meet.  
I will never take you for my love again; but I will  
always count you my deer.  

**FALSTAFF**  
I do begin to perceive that I am made an ass.  

**FORD**  
Ay, and an ox too: both the proofs are extant.  

**FALSTAFF**  
And these are not fairies? I was three or four  
times in the thought they were not fairies: and yet  
the guiltiness of my mind, the sudden surprise of my  
powers, drove the grossness of the foppery into a  
received belief, in despite of the teeth of all  
rhyme and reason, that they were fairies. See now  
how wit may be made a Jack-a-Lent, when 'tis upon  
ill employment!  

**SIR HUGH EVANS**  
Sir John Falstaff, serve Got, and leave your  
desires, and fairies will not pinse you.  

**FORD**  
Well said, fairy Hugh.  

**SIR HUGH EVANS**  
And leave your jealousies too, I pray you.  

**FORD**  
I will never mistrust my wife again till thou art  
able to woo her in good English.  

**FALSTAFF**  
Have I laid my brain in the sun and dried it, that  
it wants matter to prevent so gross o'erreaching as  
this? Am I ridden with a Welsh goat too? shall I  
have a coxcomb of frize? 'Tis time I were choked  
with a piece of toasted cheese.  

**SIR HUGH EVANS**  
Seese is not good to give putter; your belly is all putter.  

**FALSTAFF**  
'Seese' and 'putter'! have I lived to stand at the  
taunt of one that makes fritters of English? This  
is enough to be the decay of lust and late-walking  
through the realm.  

**MISTRESS PAGE**  
Why Sir John, do you think, though we would have the  
virtue out of our hearts by the head and shoulders  
and have given ourselves without scruple to hell,  
that ever the devil could have made you our delight?  

**FORD**  
What, a hodge-pudding? a bag of flax?  

**MISTRESS PAGE**  
A puffed man?  

**PAGE**  
Old, cold, withered and of intolerable entrails?  

**FORD**  
And one that is as slanderous as Satan?  

**PAGE**  
And as poor as Job?  

**FORD**  
And as wicked as his wife?  

**SIR HUGH EVANS**  
And given to fornications, and to taverns and sack  
and wine and metheglins, and to drinkings and  
swearings and starings, pribbles and prabbles?  

**FALSTAFF**  
Well, I am your theme: you have the start of me; I  
am dejected; I am not able to answer the Welsh  
flannel; ignorance itself is a plummet o'er me: use  
me as you will.  

**FORD**  
Marry, sir, we'll bring you to Windsor, to one  
Master Brook, that you have cozened of money, to  
whom you should have been a pander: over and above  
that you have suffered, I think to repay that money  
will be a biting affliction.  

**PAGE**  
Yet be cheerful, knight: thou shalt eat a posset  
to-night at my house; where I will desire thee to  
laugh at my wife, that now laughs at thee: tell her  
Master Slender hath married her daughter.  

**MISTRESS PAGE**  
[Aside]_  
Doctors doubt that: if Anne Page be my  
daughter, she is, by this, Doctor Caius' wife.  

_Enter SLENDER_

**SLENDER**  
Whoa ho! ho, father Page!  

**PAGE**  
Son, how now! how now, son! have you dispatched?  

**SLENDER**  
Dispatched! I'll make the best in Gloucestershire  
know on't; would I were hanged, la, else.  

**PAGE**  
Of what, son?  

**SLENDER**  
I came yonder at Eton to marry Mistress Anne Page,  
and she's a great lubberly boy. If it had not been  
i' the church, I would have swinged him, or he  
should have swinged me. If I did not think it had  
been Anne Page, would I might never stir!--and 'tis  
a postmaster's boy.  

**PAGE**  
Upon my life, then, you took the wrong.  

**SLENDER**  
What need you tell me that? I think so, when I took  
a boy for a girl. If I had been married to him, for  
all he was in woman's apparel, I would not have had  
him.  

**PAGE**  
Why, this is your own folly. Did not I tell you how  
you should know my daughter by her garments?  

**SLENDER**  
I went to her in white, and cried 'mum,' and she  
cried 'budget,' as Anne and I had appointed; and yet  
it was not Anne, but a postmaster's boy.  

**MISTRESS PAGE**  
Good George, be not angry: I knew of your purpose;  
turned my daughter into green; and, indeed, she is  
now with the doctor at the deanery, and there married.  

_Enter DOCTOR CAIUS_

**DOCTOR CAIUS**  
Vere is Mistress Page? By gar, I am cozened: I ha'  
married un garcon, a boy; un paysan, by gar, a boy;  
it is not Anne Page: by gar, I am cozened.  

**MISTRESS PAGE**  
Why, did you take her in green?  

**DOCTOR CAIUS**  
Ay, by gar, and 'tis a boy: by gar, I'll raise all Windsor.  

_Exit_

**FORD**  
This is strange. Who hath got the right Anne?  

**PAGE**  
My heart misgives me: here comes Master Fenton.  

_Enter FENTON and ANNE PAGE_

How now, Master Fenton!  

**ANNE PAGE**  
Pardon, good father! good my mother, pardon!  

**PAGE**  
Now, mistress, how chance you went not with Master Slender?  

**MISTRESS PAGE**  
Why went you not with master doctor, maid?  

**FENTON**  
You do amaze her: hear the truth of it.  
You would have married her most shamefully,  
Where there was no proportion held in love.  
The truth is, she and I, long since contracted,  
Are now so sure that nothing can dissolve us.  
The offence is holy that she hath committed;  
And this deceit loses the name of craft,  
Of disobedience, or unduteous title,  
Since therein she doth evitate and shun  
A thousand irreligious cursed hours,  
Which forced marriage would have brought upon her.  

**FORD**  
Stand not amazed; here is no remedy:  
In love the heavens themselves do guide the state;  
Money buys lands, and wives are sold by fate.  

**FALSTAFF**  
I am glad, though you have ta'en a special stand to  
strike at me, that your arrow hath glanced.  

**PAGE**  
Well, what remedy? Fenton, heaven give thee joy!  
What cannot be eschew'd must be embraced.  

**FALSTAFF**  
When night-dogs run, all sorts of deer are chased.  

**MISTRESS PAGE**  
Well, I will muse no further. Master Fenton,  
Heaven give you many, many merry days!  
Good husband, let us every one go home,  
And laugh this sport o'er by a country fire;  
Sir John and all.  

**FORD**  
Let it be so. Sir John,  
To Master Brook you yet shall hold your word  
For he tonight shall lie with Mistress Ford.  

_Exeunt_
